/*! uswds v1.1.0 */
html {
  box-sizing: border-box;
}

*, *::after, *::before {
  box-sizing: inherit;
}

/*! normalize.css v3.0.3 | MIT License | github.com/necolas/normalize.css */
/**
 * 1. Set default font family to sans-serif.
 * 2. Prevent iOS and IE text size adjust after device orientation change,
 *    without disabling user zoom.
 */
html {
  font-family: sans-serif;
  /* 1 */
  -ms-text-size-adjust: 100%;
  /* 2 */
  -webkit-text-size-adjust: 100%;
  /* 2 */
}

/**
 * Remove default margin.
 */
body {
  margin: 0;
}

/* HTML5 display definitions
   ========================================================================== */
/**
 * Correct `block` display not defined for any HTML5 element in IE 8/9.
 * Correct `block` display not defined for `details` or `summary` in IE 10/11
 * and Firefox.
 * Correct `block` display not defined for `main` in IE 11.
 */
article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
main,
menu,
nav,
section,
summary {
  display: block;
}

/**
 * 1. Correct `inline-block` display not defined in IE 8/9.
 * 2. Normalize vertical alignment of `progress` in Chrome, Firefox, and Opera.
 */
audio,
canvas,
progress,
video {
  display: inline-block;
  /* 1 */
  vertical-align: baseline;
  /* 2 */
}

/**
 * Prevent modern browsers from displaying `audio` without controls.
 * Remove excess height in iOS 5 devices.
 */
audio:not([controls]) {
  display: none;
  height: 0;
}

/**
 * Address `[hidden]` styling not present in IE 8/9/10.
 * Hide the `template` element in IE 8/9/10/11, Safari, and Firefox < 22.
 */
[hidden],
template {
  display: none;
}

/* Links
   ========================================================================== */
/**
 * Remove the gray background color from active links in IE 10.
 */
a {
  background-color: transparent;
}

/**
 * Improve readability of focused elements when they are also in an
 * active/hover state.
 */
a:active,
a:hover {
  outline: 0;
}

/* Text-level semantics
   ========================================================================== */
/**
 * Address styling not present in IE 8/9/10/11, Safari, and Chrome.
 */
abbr[title] {
  border-bottom: 1px dotted;
}

/**
 * Address style set to `bolder` in Firefox 4+, Safari, and Chrome.
 */
b,
strong {
  font-weight: bold;
}

/**
 * Address styling not present in Safari and Chrome.
 */
dfn {
  font-style: italic;
}

/**
 * Address variable `h1` font-size and margin within `section` and `article`
 * contexts in Firefox 4+, Safari, and Chrome.
 */
h1 {
  font-size: 2em;
  margin: 0.67em 0;
}

/**
 * Address styling not present in IE 8/9.
 */
mark {
  background: #ff0;
  color: #000;
}

/**
 * Address inconsistent and variable font size in all browsers.
 */
small {
  font-size: 80%;
}

/**
 * Prevent `sub` and `sup` affecting `line-height` in all browsers.
 */
sub,
sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline;
}

sup {
  top: -0.5em;
}

sub {
  bottom: -0.25em;
}

/* Embedded content
   ========================================================================== */
/**
 * Remove border when inside `a` element in IE 8/9/10.
 */
img {
  border: 0;
}

/**
 * Correct overflow not hidden in IE 9/10/11.
 */
svg:not(:root) {
  overflow: hidden;
}

/* Grouping content
   ========================================================================== */
/**
 * Address margin not present in IE 8/9 and Safari.
 */
figure {
  margin: 1em 40px;
}

/**
 * Address differences between Firefox and other browsers.
 */
hr {
  box-sizing: content-box;
  height: 0;
}

/**
 * Contain overflow in all browsers.
 */
pre {
  overflow: auto;
}

/**
 * Address odd `em`-unit font size rendering in all browsers.
 */
code,
kbd,
pre,
samp {
  font-family: monospace, monospace;
  font-size: 1em;
}

/* Forms
   ========================================================================== */
/**
 * Known limitation: by default, Chrome and Safari on OS X allow very limited
 * styling of `select`, unless a `border` property is set.
 */
/**
 * 1. Correct color not being inherited.
 *    Known issue: affects color of disabled elements.
 * 2. Correct font properties not being inherited.
 * 3. Address margins set differently in Firefox 4+, Safari, and Chrome.
 */
button,
input,
optgroup,
select,
textarea {
  color: inherit;
  /* 1 */
  font: inherit;
  /* 2 */
  margin: 0;
  /* 3 */
}

/**
 * Address `overflow` set to `hidden` in IE 8/9/10/11.
 */
button {
  overflow: visible;
}

/**
 * Address inconsistent `text-transform` inheritance for `button` and `select`.
 * All other form control elements do not inherit `text-transform` values.
 * Correct `button` style inheritance in Firefox, IE 8/9/10/11, and Opera.
 * Correct `select` style inheritance in Firefox.
 */
button,
select {
  text-transform: none;
}

/**
 * 1. Avoid the WebKit bug in Android 4.0.* where (2) destroys native `audio`
 *    and `video` controls.
 * 2. Correct inability to style clickable `input` types in iOS.
 * 3. Improve usability and consistency of cursor style between image-type
 *    `input` and others.
 */
button,
html input[type="button"],
input[type="reset"],
input[type="submit"] {
  -webkit-appearance: button;
  /* 2 */
  cursor: pointer;
  /* 3 */
}

/**
 * Re-set default cursor for disabled elements.
 */
button[disabled],
html input[disabled] {
  cursor: default;
}

/**
 * Remove inner padding and border in Firefox 4+.
 */
button::-moz-focus-inner,
input::-moz-focus-inner {
  border: 0;
  padding: 0;
}

/**
 * Address Firefox 4+ setting `line-height` on `input` using `!important` in
 * the UA stylesheet.
 */
input {
  line-height: normal;
}

/**
 * It's recommended that you don't attempt to style these elements.
 * Firefox's implementation doesn't respect box-sizing, padding, or width.
 *
 * 1. Address box sizing set to `content-box` in IE 8/9/10.
 * 2. Remove excess padding in IE 8/9/10.
 */
input[type="checkbox"],
input[type="radio"] {
  box-sizing: border-box;
  /* 1 */
  padding: 0;
  /* 2 */
}

/**
 * Fix the cursor style for Chrome's increment/decrement buttons. For certain
 * `font-size` values of the `input`, it causes the cursor style of the
 * decrement button to change from `default` to `text`.
 */
input[type="number"]::-webkit-inner-spin-button,
input[type="number"]::-webkit-outer-spin-button {
  height: auto;
}

/**
 * 1. Address `appearance` set to `searchfield` in Safari and Chrome.
 * 2. Address `box-sizing` set to `border-box` in Safari and Chrome.
 */
input[type="search"] {
  -webkit-appearance: textfield;
  /* 1 */
  box-sizing: content-box;
  /* 2 */
}

/**
 * Remove inner padding and search cancel button in Safari and Chrome on OS X.
 * Safari (but not Chrome) clips the cancel button when the search input has
 * padding (and `textfield` appearance).
 */
input[type="search"]::-webkit-search-cancel-button,
input[type="search"]::-webkit-search-decoration {
  -webkit-appearance: none;
}

/**
 * Define consistent border, margin, and padding.
 */
fieldset {
  border: 1px solid #c0c0c0;
  margin: 0 2px;
  padding: 0.35em 0.625em 0.75em;
}

/**
 * 1. Correct `color` not being inherited in IE 8/9/10/11.
 * 2. Remove padding so people aren't caught out if they zero out fieldsets.
 */
legend {
  border: 0;
  /* 1 */
  padding: 0;
  /* 2 */
}

/**
 * Remove default vertical scrollbar in IE 8/9/10/11.
 */
textarea {
  overflow: auto;
}

/**
 * Don't inherit the `font-weight` (applied by a rule above).
 * NOTE: the default cannot safely be changed in Chrome and Safari on OS X.
 */
optgroup {
  font-weight: bold;
}

/* Tables
   ========================================================================== */
/**
 * Remove most spacing between table cells.
 */
table {
  border-collapse: collapse;
  border-spacing: 0;
}

td,
th {
  padding: 0;
}

/* stylelint-disable at-rule-empty-line-before */
@font-face {
  font-family: "Source Sans Pro";
  font-style: normal;
  font-weight: 300;
  src: url("../fonts/sourcesanspro-light-webfont.eot?#iefix") format("embedded-opentype"), url("../fonts/sourcesanspro-light-webfont.woff2") format("woff2"), url("../fonts/sourcesanspro-light-webfont.woff") format("woff"), url("../fonts/sourcesanspro-light-webfont.ttf") format("truetype");
}

@font-face {
  font-family: "Source Sans Pro";
  font-style: normal;
  font-weight: 400;
  src: url("../fonts/sourcesanspro-regular-webfont.eot?#iefix") format("embedded-opentype"), url("../fonts/sourcesanspro-regular-webfont.woff2") format("woff2"), url("../fonts/sourcesanspro-regular-webfont.woff") format("woff"), url("../fonts/sourcesanspro-regular-webfont.ttf") format("truetype");
}

@font-face {
  font-family: "Source Sans Pro";
  font-style: italic;
  font-weight: 400;
  src: url("../fonts/sourcesanspro-italic-webfont.eot?#iefix") format("embedded-opentype"), url("../fonts/sourcesanspro-italic-webfont.woff2") format("woff2"), url("../fonts/sourcesanspro-italic-webfont.woff") format("woff"), url("../fonts/sourcesanspro-italic-webfont.ttf") format("truetype");
}

@font-face {
  font-family: "Source Sans Pro";
  font-style: normal;
  font-weight: 700;
  src: url("../fonts/sourcesanspro-bold-webfont.eot?#iefix") format("embedded-opentype"), url("../fonts/sourcesanspro-bold-webfont.woff2") format("woff2"), url("../fonts/sourcesanspro-bold-webfont.woff") format("woff"), url("../fonts/sourcesanspro-bold-webfont.ttf") format("truetype");
}

@font-face {
  font-family: "Merriweather";
  font-style: normal;
  font-weight: 300;
  src: url("../fonts/merriweather-light-webfont.eot?#iefix") format("embedded-opentype"), url("../fonts/merriweather-light-webfont.woff2") format("woff2"), url("../fonts/merriweather-light-webfont.woff") format("woff"), url("../fonts/merriweather-light-webfont.ttf") format("truetype");
}

@font-face {
  font-family: "Merriweather";
  font-style: normal;
  font-weight: 400;
  src: url("../fonts/merriweather-regular-webfont.eot?#iefix") format("embedded-opentype"), url("../fonts/merriweather-regular-webfont.woff2") format("woff2"), url("../fonts/merriweather-regular-webfont.woff") format("woff"), url("../fonts/merriweather-regular-webfont.ttf") format("truetype");
}

@font-face {
  font-family: "Merriweather";
  font-style: italic;
  font-weight: 400;
  src: url("../fonts/merriweather-italic-webfont.eot?#iefix") format("embedded-opentype"), url("../fonts/merriweather-italic-webfont.woff2") format("woff2"), url("../fonts/merriweather-italic-webfont.woff") format("woff"), url("../fonts/merriweather-italic-webfont.ttf") format("truetype");
}

@font-face {
  font-family: "Merriweather";
  font-style: normal;
  font-weight: 700;
  src: url("../fonts/merriweather-bold-webfont.eot?#iefix") format("embedded-opentype"), url("../fonts/merriweather-bold-webfont.woff2") format("woff2"), url("../fonts/merriweather-bold-webfont.woff") format("woff"), url("../fonts/merriweather-bold-webfont.ttf") format("truetype");
}

/* stylelint-enable */
html {
  box-sizing: border-box;
}

*,
*::before,
*::after {
  box-sizing: inherit;
}

body {
  background-color: #ffffff;
  overflow-x: hidden;
}

.lt-ie9 * {
  -webkit-filter: none !important;
  filter: none !important;
  /* stylelint-disable-line declaration-no-important */
}

[hidden] {
  display: none !important;
  /* stylelint-disable-line declaration-no-important */
}

.usa-grid,
.usa-grid-full {
  max-width: 1200px;
  margin-left: auto;
  margin-right: auto;
  max-width: 1040px;
}

.usa-grid::after,
.usa-grid-full::after {
  clear: both;
  content: "";
  display: block;
}

.usa-grid {
  padding-right: 1.5rem;
  padding-left: 1.5rem;
}

@media screen and (min-width: 600px) {
  .usa-grid {
    padding-right: 3rem;
    padding-left: 3rem;
  }
}

.usa-grid-full {
  padding: 0;
}

@media screen and (min-width: 600px) {
  .usa-width-one-whole {
    float: left;
    display: block;
    margin-right: 4.82916%;
    width: 100%;
  }
  .usa-width-one-whole:last-child {
    margin-right: 0;
  }
  .usa-width-one-half {
    float: left;
    display: block;
    margin-right: 4.82916%;
    width: 47.58542%;
  }
  .usa-width-one-half:last-child {
    margin-right: 0;
  }
  .usa-width-one-third {
    float: left;
    display: block;
    margin-right: 4.82916%;
    width: 30.11389%;
  }
  .usa-width-one-third:last-child {
    margin-right: 0;
  }
  .usa-width-two-thirds {
    float: left;
    display: block;
    margin-right: 4.82916%;
    width: 65.05695%;
  }
  .usa-width-two-thirds:last-child {
    margin-right: 0;
  }
  .usa-width-one-fourth {
    float: left;
    display: block;
    margin-right: 4.82916%;
    width: 47.58542%;
  }
  .usa-width-one-fourth:last-child {
    margin-right: 0;
  }
  .usa-width-one-fourth:nth-child(2n) {
    margin-right: 0;
  }
  .usa-width-three-fourths {
    float: left;
    display: block;
    margin-right: 4.82916%;
    width: 100%;
  }
  .usa-width-three-fourths:last-child {
    margin-right: 0;
  }
  .usa-width-one-sixth {
    float: left;
    display: block;
    margin-right: 4.82916%;
    width: 30.11389%;
  }
  .usa-width-one-sixth:last-child {
    margin-right: 0;
  }
  .usa-width-one-sixth:nth-child(3n) {
    margin-right: 0;
  }
  .usa-width-five-sixths {
    float: left;
    display: block;
    margin-right: 4.82916%;
    width: 65.05695%;
  }
  .usa-width-five-sixths:last-child {
    margin-right: 0;
  }
  .usa-width-one-twelfth {
    float: left;
    display: block;
    margin-right: 4.82916%;
    width: 30.11389%;
  }
  .usa-width-one-twelfth:last-child {
    margin-right: 0;
  }
  .usa-width-one-twelfth:nth-child(3n) {
    margin-right: 0;
  }
  .usa-width-five-twelfths {
    float: left;
    display: block;
    margin-right: 4.82916%;
    width: 30.11389%;
  }
  .usa-width-five-twelfths:last-child {
    margin-right: 0;
  }
  .usa-width-seven-twelfths {
    float: left;
    display: block;
    margin-right: 4.82916%;
    width: 65.05695%;
  }
  .usa-width-seven-twelfths:last-child {
    margin-right: 0;
  }
}

@media screen and (min-width: 1201px) {
  .usa-width-one-whole {
    float: left;
    display: block;
    margin-right: 2.35765%;
    width: 100%;
  }
  .usa-width-one-whole:last-child {
    margin-right: 0;
  }
  .usa-width-one-half {
    float: left;
    display: block;
    margin-right: 2.35765%;
    width: 48.82117%;
  }
  .usa-width-one-half:last-child {
    margin-right: 0;
  }
  .usa-width-one-third {
    float: left;
    display: block;
    margin-right: 2.35765%;
    width: 31.76157%;
  }
  .usa-width-one-third:last-child {
    margin-right: 0;
  }
  .usa-width-two-thirds {
    float: left;
    display: block;
    margin-right: 2.35765%;
    width: 65.88078%;
  }
  .usa-width-two-thirds:last-child {
    margin-right: 0;
  }
  .usa-width-one-fourth {
    float: left;
    display: block;
    margin-right: 2.35765%;
    width: 23.23176%;
  }
  .usa-width-one-fourth:last-child {
    margin-right: 0;
  }
  .usa-width-one-fourth:nth-child(2n) {
    float: left;
    display: block;
    margin-right: 2.35765%;
    width: 23.23176%;
  }
  .usa-width-one-fourth:nth-child(2n):last-child {
    margin-right: 0;
  }
  .usa-width-one-fourth:nth-child(4n) {
    margin-right: 0;
  }
  .usa-width-three-fourths {
    float: left;
    display: block;
    margin-right: 2.35765%;
    width: 74.41059%;
  }
  .usa-width-three-fourths:last-child {
    margin-right: 0;
  }
  .usa-width-one-sixth {
    float: left;
    display: block;
    margin-right: 2.35765%;
    width: 14.70196%;
  }
  .usa-width-one-sixth:last-child {
    margin-right: 0;
  }
  .usa-width-one-sixth:nth-child(3n) {
    float: left;
    display: block;
    margin-right: 2.35765%;
    width: 14.70196%;
  }
  .usa-width-one-sixth:nth-child(3n):last-child {
    margin-right: 0;
  }
  .usa-width-one-sixth:nth-child(6n) {
    margin-right: 0;
  }
  .usa-width-five-sixths {
    float: left;
    display: block;
    margin-right: 2.35765%;
    width: 82.94039%;
  }
  .usa-width-five-sixths:last-child {
    margin-right: 0;
  }
  .usa-width-one-twelfth {
    float: left;
    display: block;
    margin-right: 2.35765%;
    width: 6.17215%;
  }
  .usa-width-one-twelfth:last-child {
    margin-right: 0;
  }
  .usa-width-one-twelfth:nth-child(3n) {
    float: left;
    display: block;
    margin-right: 2.35765%;
    width: 6.17215%;
  }
  .usa-width-one-twelfth:nth-child(3n):last-child {
    margin-right: 0;
  }
  .usa-width-one-twelfth:nth-child(12n) {
    margin-right: 0;
  }
  .usa-width-five-twelfths {
    float: left;
    display: block;
    margin-right: 2.35765%;
    width: 40.29137%;
  }
  .usa-width-five-twelfths:last-child {
    margin-right: 0;
  }
  .usa-width-seven-twelfths {
    float: left;
    display: block;
    margin-right: 2.35765%;
    width: 57.35098%;
  }
  .usa-width-seven-twelfths:last-child {
    margin-right: 0;
  }
}

.usa-end-row {
  margin-right: 0;
}

.usa-sr-only {
  position: absolute;
  left: -999em;
}

/* stylelint-disable selector-no-qualifying-type */
.usa-button,
.usa-button-primary,
.usa-button:visited,
.usa-button-primary:visited,
button,
[type=button],
[type=submit],
[type=reset],
[type=image] {
  -moz-osx-font-smoothing: grayscale;
  -webkit-font-smoothing: antialiased;
  margin-top: 0.5em;
  margin-right: 0.5em;
  margin-bottom: 0.5em;
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
  background-color: #0071bc;
  border: 0;
  border-radius: 0.3rem;
  color: #ffffff;
  cursor: pointer;
  display: inline-block;
  font-family: "Source Sans Pro", "Helvetica Neue", "Helvetica", "Roboto", "Arial", sans-serif;
  font-size: 1.7rem;
  font-weight: 700;
  line-height: 1;
  outline: none;
  padding: 1rem 2rem;
  text-align: center;
  text-decoration: none;
  width: 100%;
}

@media screen and (min-width: 481px) {
  .usa-button,
  .usa-button-primary,
  .usa-button:visited,
  .usa-button-primary:visited,
  button,
  [type=button],
  [type=submit],
  [type=reset],
  [type=image] {
    width: auto;
  }
}

.usa-button:hover, .usa-button.usa-button-hover,
.usa-button-primary:hover,
.usa-button-primary.usa-button-hover,
.usa-button:visited:hover,
.usa-button:visited.usa-button-hover,
.usa-button-primary:visited:hover,
.usa-button-primary:visited.usa-button-hover,
button:hover,
button.usa-button-hover,
[type=button]:hover,
[type=button].usa-button-hover,
[type=submit]:hover,
[type=submit].usa-button-hover,
[type=reset]:hover,
[type=reset].usa-button-hover,
[type=image]:hover,
[type=image].usa-button-hover {
  background-color: #205493;
  border-bottom: 0;
  color: #ffffff;
  text-decoration: none;
}

.usa-button:focus, .usa-button.usa-button-focus,
.usa-button-primary:focus,
.usa-button-primary.usa-button-focus,
.usa-button:visited:focus,
.usa-button:visited.usa-button-focus,
.usa-button-primary:visited:focus,
.usa-button-primary:visited.usa-button-focus,
button:focus,
button.usa-button-focus,
[type=button]:focus,
[type=button].usa-button-focus,
[type=submit]:focus,
[type=submit].usa-button-focus,
[type=reset]:focus,
[type=reset].usa-button-focus,
[type=image]:focus,
[type=image].usa-button-focus {
  box-shadow: 0 0 3px #3e94cf, 0 0 7px #3e94cf;
}

.usa-button:active, .usa-button.usa-button-active,
.usa-button-primary:active,
.usa-button-primary.usa-button-active,
.usa-button:visited:active,
.usa-button:visited.usa-button-active,
.usa-button-primary:visited:active,
.usa-button-primary:visited.usa-button-active,
button:active,
button.usa-button-active,
[type=button]:active,
[type=button].usa-button-active,
[type=submit]:active,
[type=submit].usa-button-active,
[type=reset]:active,
[type=reset].usa-button-active,
[type=image]:active,
[type=image].usa-button-active {
  background-color: #112e51;
}

.usa-button.usa-button-primary-alt,
.usa-button-primary.usa-button-primary-alt,
.usa-button:visited.usa-button-primary-alt,
.usa-button-primary:visited.usa-button-primary-alt,
button.usa-button-primary-alt,
[type=button].usa-button-primary-alt,
[type=submit].usa-button-primary-alt,
[type=reset].usa-button-primary-alt,
[type=image].usa-button-primary-alt {
  background-color: #02bfe7;
  color: #212121;
}

.usa-button.usa-button-primary-alt:hover, .usa-button.usa-button-primary-alt.usa-button-hover,
.usa-button-primary.usa-button-primary-alt:hover,
.usa-button-primary.usa-button-primary-alt.usa-button-hover,
.usa-button:visited.usa-button-primary-alt:hover,
.usa-button:visited.usa-button-primary-alt.usa-button-hover,
.usa-button-primary:visited.usa-button-primary-alt:hover,
.usa-button-primary:visited.usa-button-primary-alt.usa-button-hover,
button.usa-button-primary-alt:hover,
button.usa-button-primary-alt.usa-button-hover,
[type=button].usa-button-primary-alt:hover,
[type=button].usa-button-primary-alt.usa-button-hover,
[type=submit].usa-button-primary-alt:hover,
[type=submit].usa-button-primary-alt.usa-button-hover,
[type=reset].usa-button-primary-alt:hover,
[type=reset].usa-button-primary-alt.usa-button-hover,
[type=image].usa-button-primary-alt:hover,
[type=image].usa-button-primary-alt.usa-button-hover {
  background-color: #00a6d2;
}

.usa-button.usa-button-primary-alt:active, .usa-button.usa-button-primary-alt.usa-button-active,
.usa-button-primary.usa-button-primary-alt:active,
.usa-button-primary.usa-button-primary-alt.usa-button-active,
.usa-button:visited.usa-button-primary-alt:active,
.usa-button:visited.usa-button-primary-alt.usa-button-active,
.usa-button-primary:visited.usa-button-primary-alt:active,
.usa-button-primary:visited.usa-button-primary-alt.usa-button-active,
button.usa-button-primary-alt:active,
button.usa-button-primary-alt.usa-button-active,
[type=button].usa-button-primary-alt:active,
[type=button].usa-button-primary-alt.usa-button-active,
[type=submit].usa-button-primary-alt:active,
[type=submit].usa-button-primary-alt.usa-button-active,
[type=reset].usa-button-primary-alt:active,
[type=reset].usa-button-primary-alt.usa-button-active,
[type=image].usa-button-primary-alt:active,
[type=image].usa-button-primary-alt.usa-button-active {
  background-color: #046b99;
  color: #ffffff;
}

.usa-button.usa-button-secondary,
.usa-button-primary.usa-button-secondary,
.usa-button:visited.usa-button-secondary,
.usa-button-primary:visited.usa-button-secondary,
button.usa-button-secondary,
[type=button].usa-button-secondary,
[type=submit].usa-button-secondary,
[type=reset].usa-button-secondary,
[type=image].usa-button-secondary {
  background-color: #e31c3d;
}

.usa-button.usa-button-secondary:hover, .usa-button.usa-button-secondary.usa-button-hover,
.usa-button-primary.usa-button-secondary:hover,
.usa-button-primary.usa-button-secondary.usa-button-hover,
.usa-button:visited.usa-button-secondary:hover,
.usa-button:visited.usa-button-secondary.usa-button-hover,
.usa-button-primary:visited.usa-button-secondary:hover,
.usa-button-primary:visited.usa-button-secondary.usa-button-hover,
button.usa-button-secondary:hover,
button.usa-button-secondary.usa-button-hover,
[type=button].usa-button-secondary:hover,
[type=button].usa-button-secondary.usa-button-hover,
[type=submit].usa-button-secondary:hover,
[type=submit].usa-button-secondary.usa-button-hover,
[type=reset].usa-button-secondary:hover,
[type=reset].usa-button-secondary.usa-button-hover,
[type=image].usa-button-secondary:hover,
[type=image].usa-button-secondary.usa-button-hover {
  background-color: #cd2026;
}

.usa-button.usa-button-secondary:active, .usa-button.usa-button-secondary.usa-button-active,
.usa-button-primary.usa-button-secondary:active,
.usa-button-primary.usa-button-secondary.usa-button-active,
.usa-button:visited.usa-button-secondary:active,
.usa-button:visited.usa-button-secondary.usa-button-active,
.usa-button-primary:visited.usa-button-secondary:active,
.usa-button-primary:visited.usa-button-secondary.usa-button-active,
button.usa-button-secondary:active,
button.usa-button-secondary.usa-button-active,
[type=button].usa-button-secondary:active,
[type=button].usa-button-secondary.usa-button-active,
[type=submit].usa-button-secondary:active,
[type=submit].usa-button-secondary.usa-button-active,
[type=reset].usa-button-secondary:active,
[type=reset].usa-button-secondary.usa-button-active,
[type=image].usa-button-secondary:active,
[type=image].usa-button-secondary.usa-button-active {
  background-color: #981b1e;
}

.usa-button.usa-button-gray,
.usa-button-primary.usa-button-gray,
.usa-button:visited.usa-button-gray,
.usa-button-primary:visited.usa-button-gray,
button.usa-button-gray,
[type=button].usa-button-gray,
[type=submit].usa-button-gray,
[type=reset].usa-button-gray,
[type=image].usa-button-gray {
  background-color: #5b616b;
}

.usa-button.usa-button-gray:hover, .usa-button.usa-button-gray.usa-button-hover,
.usa-button-primary.usa-button-gray:hover,
.usa-button-primary.usa-button-gray.usa-button-hover,
.usa-button:visited.usa-button-gray:hover,
.usa-button:visited.usa-button-gray.usa-button-hover,
.usa-button-primary:visited.usa-button-gray:hover,
.usa-button-primary:visited.usa-button-gray.usa-button-hover,
button.usa-button-gray:hover,
button.usa-button-gray.usa-button-hover,
[type=button].usa-button-gray:hover,
[type=button].usa-button-gray.usa-button-hover,
[type=submit].usa-button-gray:hover,
[type=submit].usa-button-gray.usa-button-hover,
[type=reset].usa-button-gray:hover,
[type=reset].usa-button-gray.usa-button-hover,
[type=image].usa-button-gray:hover,
[type=image].usa-button-gray.usa-button-hover {
  background-color: #323a45;
}

.usa-button.usa-button-gray:active, .usa-button.usa-button-gray.usa-button-active,
.usa-button-primary.usa-button-gray:active,
.usa-button-primary.usa-button-gray.usa-button-active,
.usa-button:visited.usa-button-gray:active,
.usa-button:visited.usa-button-gray.usa-button-active,
.usa-button-primary:visited.usa-button-gray:active,
.usa-button-primary:visited.usa-button-gray.usa-button-active,
button.usa-button-gray:active,
button.usa-button-gray.usa-button-active,
[type=button].usa-button-gray:active,
[type=button].usa-button-gray.usa-button-active,
[type=submit].usa-button-gray:active,
[type=submit].usa-button-gray.usa-button-active,
[type=reset].usa-button-gray:active,
[type=reset].usa-button-gray.usa-button-active,
[type=image].usa-button-gray:active,
[type=image].usa-button-gray.usa-button-active {
  background-color: #212121;
}

.usa-button.usa-button-outline,
.usa-button-primary.usa-button-outline,
.usa-button:visited.usa-button-outline,
.usa-button-primary:visited.usa-button-outline,
button.usa-button-outline,
[type=button].usa-button-outline,
[type=submit].usa-button-outline,
[type=reset].usa-button-outline,
[type=image].usa-button-outline {
  background-color: #ffffff;
  box-shadow: inset 0 0 0 2px #0071bc;
  color: #0071bc;
}

.usa-button.usa-button-outline:hover, .usa-button.usa-button-outline.usa-button-hover,
.usa-button-primary.usa-button-outline:hover,
.usa-button-primary.usa-button-outline.usa-button-hover,
.usa-button:visited.usa-button-outline:hover,
.usa-button:visited.usa-button-outline.usa-button-hover,
.usa-button-primary:visited.usa-button-outline:hover,
.usa-button-primary:visited.usa-button-outline.usa-button-hover,
button.usa-button-outline:hover,
button.usa-button-outline.usa-button-hover,
[type=button].usa-button-outline:hover,
[type=button].usa-button-outline.usa-button-hover,
[type=submit].usa-button-outline:hover,
[type=submit].usa-button-outline.usa-button-hover,
[type=reset].usa-button-outline:hover,
[type=reset].usa-button-outline.usa-button-hover,
[type=image].usa-button-outline:hover,
[type=image].usa-button-outline.usa-button-hover {
  box-shadow: inset 0 0 0 2px #205493;
  color: #205493;
}

.usa-button.usa-button-outline:active, .usa-button.usa-button-outline.usa-button-active,
.usa-button-primary.usa-button-outline:active,
.usa-button-primary.usa-button-outline.usa-button-active,
.usa-button:visited.usa-button-outline:active,
.usa-button:visited.usa-button-outline.usa-button-active,
.usa-button-primary:visited.usa-button-outline:active,
.usa-button-primary:visited.usa-button-outline.usa-button-active,
button.usa-button-outline:active,
button.usa-button-outline.usa-button-active,
[type=button].usa-button-outline:active,
[type=button].usa-button-outline.usa-button-active,
[type=submit].usa-button-outline:active,
[type=submit].usa-button-outline.usa-button-active,
[type=reset].usa-button-outline:active,
[type=reset].usa-button-outline.usa-button-active,
[type=image].usa-button-outline:active,
[type=image].usa-button-outline.usa-button-active {
  box-shadow: inset 0 0 0 2px #112e51;
  color: #112e51;
}

.usa-button.usa-button-outline:focus, .usa-button.usa-button-outline.usa-button-focus,
.usa-button-primary.usa-button-outline:focus,
.usa-button-primary.usa-button-outline.usa-button-focus,
.usa-button:visited.usa-button-outline:focus,
.usa-button:visited.usa-button-outline.usa-button-focus,
.usa-button-primary:visited.usa-button-outline:focus,
.usa-button-primary:visited.usa-button-outline.usa-button-focus,
button.usa-button-outline:focus,
button.usa-button-outline.usa-button-focus,
[type=button].usa-button-outline:focus,
[type=button].usa-button-outline.usa-button-focus,
[type=submit].usa-button-outline:focus,
[type=submit].usa-button-outline.usa-button-focus,
[type=reset].usa-button-outline:focus,
[type=reset].usa-button-outline.usa-button-focus,
[type=image].usa-button-outline:focus,
[type=image].usa-button-outline.usa-button-focus {
  box-shadow: inset 0 0 0 2px #112e51, 0 0 3px #3e94cf, 0 0 7px #3e94cf;
}

.usa-button.usa-button-outline-inverse,
.usa-button-primary.usa-button-outline-inverse,
.usa-button:visited.usa-button-outline-inverse,
.usa-button-primary:visited.usa-button-outline-inverse,
button.usa-button-outline-inverse,
[type=button].usa-button-outline-inverse,
[type=submit].usa-button-outline-inverse,
[type=reset].usa-button-outline-inverse,
[type=image].usa-button-outline-inverse {
  background: transparent;
  box-shadow: inset 0 0 0 2px #ffffff;
  color: #ffffff;
}

.usa-button.usa-button-outline-inverse:hover, .usa-button.usa-button-outline-inverse.usa-button-hover,
.usa-button-primary.usa-button-outline-inverse:hover,
.usa-button-primary.usa-button-outline-inverse.usa-button-hover,
.usa-button:visited.usa-button-outline-inverse:hover,
.usa-button:visited.usa-button-outline-inverse.usa-button-hover,
.usa-button-primary:visited.usa-button-outline-inverse:hover,
.usa-button-primary:visited.usa-button-outline-inverse.usa-button-hover,
button.usa-button-outline-inverse:hover,
button.usa-button-outline-inverse.usa-button-hover,
[type=button].usa-button-outline-inverse:hover,
[type=button].usa-button-outline-inverse.usa-button-hover,
[type=submit].usa-button-outline-inverse:hover,
[type=submit].usa-button-outline-inverse.usa-button-hover,
[type=reset].usa-button-outline-inverse:hover,
[type=reset].usa-button-outline-inverse.usa-button-hover,
[type=image].usa-button-outline-inverse:hover,
[type=image].usa-button-outline-inverse.usa-button-hover {
  box-shadow: inset 0 0 0 2px #d6d7d9;
  color: #d6d7d9;
}

.usa-button.usa-button-outline-inverse:active, .usa-button.usa-button-outline-inverse.usa-button-active,
.usa-button-primary.usa-button-outline-inverse:active,
.usa-button-primary.usa-button-outline-inverse.usa-button-active,
.usa-button:visited.usa-button-outline-inverse:active,
.usa-button:visited.usa-button-outline-inverse.usa-button-active,
.usa-button-primary:visited.usa-button-outline-inverse:active,
.usa-button-primary:visited.usa-button-outline-inverse.usa-button-active,
button.usa-button-outline-inverse:active,
button.usa-button-outline-inverse.usa-button-active,
[type=button].usa-button-outline-inverse:active,
[type=button].usa-button-outline-inverse.usa-button-active,
[type=submit].usa-button-outline-inverse:active,
[type=submit].usa-button-outline-inverse.usa-button-active,
[type=reset].usa-button-outline-inverse:active,
[type=reset].usa-button-outline-inverse.usa-button-active,
[type=image].usa-button-outline-inverse:active,
[type=image].usa-button-outline-inverse.usa-button-active {
  box-shadow: inset 0 0 0 2px #aeb0b5;
  color: #d6d7d9;
}

.usa-button.usa-button-outline-inverse:focus, .usa-button.usa-button-outline-inverse.usa-button-focus,
.usa-button-primary.usa-button-outline-inverse:focus,
.usa-button-primary.usa-button-outline-inverse.usa-button-focus,
.usa-button:visited.usa-button-outline-inverse:focus,
.usa-button:visited.usa-button-outline-inverse.usa-button-focus,
.usa-button-primary:visited.usa-button-outline-inverse:focus,
.usa-button-primary:visited.usa-button-outline-inverse.usa-button-focus,
button.usa-button-outline-inverse:focus,
button.usa-button-outline-inverse.usa-button-focus,
[type=button].usa-button-outline-inverse:focus,
[type=button].usa-button-outline-inverse.usa-button-focus,
[type=submit].usa-button-outline-inverse:focus,
[type=submit].usa-button-outline-inverse.usa-button-focus,
[type=reset].usa-button-outline-inverse:focus,
[type=reset].usa-button-outline-inverse.usa-button-focus,
[type=image].usa-button-outline-inverse:focus,
[type=image].usa-button-outline-inverse.usa-button-focus {
  box-shadow: inset 0 0 0 2px #aeb0b5, 0 0 3px #3e94cf, 0 0 7px #3e94cf;
}

.usa-button.usa-button-big,
.usa-button-primary.usa-button-big,
.usa-button:visited.usa-button-big,
.usa-button-primary:visited.usa-button-big,
button.usa-button-big,
[type=button].usa-button-big,
[type=submit].usa-button-big,
[type=reset].usa-button-big,
[type=image].usa-button-big {
  font-size: 1.9rem;
  padding: 1.5rem 3rem;
}

/* stylelint-disable */
.usa-button:disabled,
.usa-button-disabled {
  background-color: #d6d7d9;
  color: #323a45;
  pointer-events: none;
}

.usa-button:disabled:hover, .usa-button:disabled.usa-button-hover, .usa-button:disabled:active, .usa-button:disabled.usa-button-active, .usa-button:disabled:focus,
.usa-button-disabled:hover,
.usa-button-disabled.usa-button-hover,
.usa-button-disabled:active,
.usa-button-disabled.usa-button-active,
.usa-button-disabled:focus {
  background-color: #d6d7d9;
  border: 0;
  box-shadow: none;
  color: #323a45;
}

.usa-button-unstyled {
  background-color: transparent;
  border: 0;
  border-radius: 0;
  font-weight: 400;
  margin: 0;
  outline: 0;
  padding: 0;
  text-align: left;
  -webkit-font-smoothing: auto;
}

.usa-button-unstyled:hover {
  background-color: transparent;
}

.usa-embed-container iframe,
.usa-embed-container object,
.usa-embed-container embed {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}

.usa-embed-container {
  padding-bottom: 56.25%;
  position: relative;
  height: 0;
  overflow: hidden;
  max-width: 100%;
}

img {
  max-width: 100%;
}

.media_link {
  display: inline-block;
  line-height: 0;
}

/* stylelint-disable selector-no-qualifying-type */
input,
textarea,
select {
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
  border: 1px solid #5b616b;
  border-radius: 0;
  box-sizing: border-box;
  color: #212121;
  display: block;
  font-size: 1.7rem;
  height: 4.4rem;
  line-height: 1.3;
  margin: 0.2em 0;
  max-width: 46rem;
  outline: none;
  padding: 1rem 0.7em;
  width: 100%;
}

input:focus, input.usa-input-focus,
textarea:focus,
textarea.usa-input-focus,
select:focus,
select.usa-input-focus {
  box-shadow: 0 0 3px #3e94cf, 0 0 7px #3e94cf;
}

input.usa-input-success,
textarea.usa-input-success,
select.usa-input-success {
  border: 3px solid #4aa564;
}

/* stylelint-enable */
.usa-input-error {
  border-left: 4px solid #cd2026;
  margin-top: 3rem;
  padding-bottom: 0.8rem;
  padding-left: 1.5rem;
  padding-top: 0.8rem;
  position: relative;
  right: 1.9rem;
}

.usa-input-error input,
.usa-input-error textarea,
.usa-input-error select {
  border: 3px solid #cd2026;
  width: calc(100% + 1.9rem);
}

.usa-input-error label {
  margin-top: 0;
}

.usa-input-error .usa-input-inline {
  border: 1px solid #5b616b;
  width: inherit;
}

.usa-input-error .usa-input-inline-error {
  border: 3px solid #cd2026;
}

.usa-input-error-label {
  display: block;
  font-size: 1.7rem;
  font-weight: 700;
}

.usa-input-error-message {
  color: #cd2026;
  display: block;
  font-size: 1.7rem;
  font-weight: 700;
  padding-bottom: 3px;
  padding-top: 3px;
}

.usa-input-required:after {
  color: #981b1e;
  content: ' (*Required)';
}

label {
  display: block;
  margin-top: 3rem;
  max-width: 46rem;
}

textarea {
  height: 16rem;
}

select {
  -moz-appearance: none;
  -webkit-appearance: none;
  appearance: none;
  background-color: #ffffff;
  background-image: url("../img/arrow-down.png");
  background-image: url("../img/arrow-down.svg");
  background-position: right 1.3rem center;
  background-repeat: no-repeat;
  background-size: 1.3rem;
}

legend {
  font-size: 3rem;
  font-weight: 700;
}

.usa-fieldset-inputs label {
  margin-top: 0;
}

.usa-form-hint {
  color: #757575;
  font-family: "Source Sans Pro", "Helvetica Neue", "Helvetica", "Roboto", "Arial", sans-serif;
  margin-bottom: 0;
}

[type=checkbox],
[type=radio] {
  margin-left: -2rem;
  opacity: 0;
  position: absolute;
}

.lt-ie9 [type=checkbox], .lt-ie9
[type=radio] {
  border: 0;
  float: left;
  margin: 0.4em 0.4em 0 0;
  position: static;
  width: auto;
}

[type=checkbox] + label,
[type=radio] + label {
  cursor: pointer;
  font-weight: 400;
  margin-bottom: 0.5em;
}

[type=checkbox] + label::before,
[type=radio] + label::before {
  background: #ffffff;
  border-radius: 0.3rem;
  box-shadow: 0 0 0 1px #757575;
  content: '\a0';
  display: inline-block;
  height: 1.8rem;
  line-height: 1.8rem;
  margin-right: 0.6em;
  text-indent: 0.15em;
  vertical-align: middle\0;
  width: 1.8rem;
}

[type=radio] + label::before {
  box-shadow: 0 0 0 2px #ffffff, 0 0 0 3px #757575;
  height: 1.6rem;
  line-height: 1.6rem;
  width: 1.6rem;
  border-radius: 100%;
}

[type=checkbox]:checked + label::before,
[type=radio]:checked + label::before {
  background-color: #0071bc;
  box-shadow: 0 0 0 1px #0071bc;
}

[type=radio]:checked + label::before {
  box-shadow: 0 0 0 2px #ffffff, 0 0 0 4px #0071bc;
}

[type=radio]:focus + label::before {
  box-shadow: 0 0 0 2px #ffffff, 0 0 0 4px #0071bc, 0 0 3px 4px #3e94cf, 0 0 7px 4px #3e94cf;
}

[type=checkbox]:checked + label::before,
[type=checkbox]:checked:disabled + label::before {
  background-image: url("../img/correct8.png");
  background-image: url("../img/correct8.svg");
  background-position: 50%;
  background-repeat: no-repeat;
}

[type=checkbox]:focus + label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 3px #0071bc;
}

[type=checkbox]:disabled + label {
  color: #5b616b;
}

[type=checkbox]:disabled + label::before,
[type=radio]:disabled + label::before {
  background: #d6d7d9;
  box-shadow: 0 0 0 1px #aeb0b5;
  cursor: not-allowed;
}

[type=range] {
  -webkit-appearance: none;
  border: none;
  padding-left: 0;
  width: 100%;
}

[type=range]:focus {
  box-shadow: none;
  outline: none;
}

[type=range]::-webkit-slider-runnable-track {
  background: #aeb0b5;
  border: 1px solid #757575;
  cursor: pointer;
  height: 1.2rem;
  width: 100%;
}

[type=range]::-moz-range-track {
  background: #0071bc;
  border: 1px solid #757575;
  cursor: pointer;
  height: 1.2rem;
  width: 100%;
}

[type=range]::-ms-track {
  background: transparent;
  color: transparent;
  cursor: pointer;
  height: 1.2rem;
  width: 100%;
}

[type=range]::-webkit-slider-thumb {
  -webkit-appearance: none;
  border: 1px solid #757575;
  height: 2.2rem;
  border-radius: 1.5rem;
  background: #f1f1f1;
  cursor: pointer;
  margin-top: -.65rem;
  width: 2.2rem;
}

[type=range]::-moz-range-thumb {
  background: #f1f1f1;
  border: 1px solid #757575;
  border-radius: 1.5rem;
  cursor: pointer;
  height: 2.2rem;
  width: 2.2rem;
}

[type=range]::-ms-thumb {
  background: #f1f1f1;
  border: 1px solid #757575;
  border-radius: 1.5rem;
  cursor: pointer;
  height: 2.2rem;
  width: 2.2rem;
}

[type=range]::-ms-fill-lower {
  background: #aeb0b5;
  border: 1px solid #757575;
  border-radius: 2rem;
}

[type=range]::-ms-fill-upper {
  background: #aeb0b5;
  border: 1px solid #757575;
  border-radius: 2rem;
}

[type=range]:focus::-webkit-slider-thumb {
  border: 2px solid #3e94cf;
}

[type=range]:focus::-moz-range-thumb {
  border: 2px solid #3e94cf;
}

[type=range]:focus::-ms-thumb {
  border: 2px solid #3e94cf;
}

.usa-date-of-birth label {
  margin-top: 0;
}

.usa-date-of-birth [type=number]::-webkit-inner-spin-button,
.usa-date-of-birth [type=number]::-webkit-outer-spin-button {
  -webkit-appearance: none;
  appearance: none;
  margin: 0;
}

.usa-date-of-birth [type=number] {
  -moz-appearance: textfield;
}

.usa-form-group-day,
.usa-form-group-month,
.usa-form-group-year {
  clear: none;
  float: left;
  margin-right: 1.5rem;
  width: 5rem;
}

.usa-form-group-year {
  width: 7rem;
}

.usa-label, .usa-label-big {
  background-color: #0071bc;
  border-radius: 0.3rem;
  color: #ffffff;
  font-size: 1.5rem;
  margin-right: 0.5rem;
  padding: 0.1rem 0.7rem;
  text-transform: uppercase;
}

.usa-label:only-of-type, .usa-label-big:only-of-type {
  margin-right: 0;
}

.usa-label-big {
  font-size: 1.7rem;
  padding-left: 0.9rem;
  padding-right: 0.9rem;
}

ul,
ol {
  margin-top: 1em;
  margin-bottom: 1em;
  padding-left: 1.94em;
}

li {
  line-height: 1.5;
  margin-bottom: 0.5em;
}

li:last-child {
  margin-bottom: 0;
}

h1 + ul,
h1 + ol,
h2 + ul,
h2 + ol,
h3 + ul,
h3 + ol,
h4 + ul,
h4 + ol,
h5 + ul,
h5 + ol,
h6 + ul,
h6 + ol,
p + ul,
p + ol {
  margin-top: 0;
}

.usa-unstyled-list {
  margin-top: 0;
  margin-bottom: 0;
  list-style-type: none;
  padding-left: 0;
}

.usa-unstyled-list > li {
  margin-bottom: 0;
}

table {
  border-spacing: 0;
  margin: 2em 0;
  min-width: 100%;
}

table thead th,
table thead td {
  background-color: #f1f1f1;
}

table th {
  text-align: left;
}

table tbody th {
  font-weight: 400;
}

table th,
table td {
  background-color: #ffffff;
  border: 1px solid #5b616b;
  padding: 1.5rem;
}

.usa-table-borderless thead tr {
  background-color: transparent;
}

.usa-table-borderless thead th {
  border-top: 0;
}

.usa-table-borderless th,
.usa-table-borderless td {
  border-left: 0;
  border-right: 0;
}

html {
  font-family: "Source Sans Pro", "Helvetica Neue", "Helvetica", "Roboto", "Arial", sans-serif;
  font-size: 10px;
}

body {
  font-size: 1.7rem;
}

p {
  line-height: 1.5;
  margin-bottom: 1em;
  margin-top: 1em;
}

a {
  color: #0071bc;
  text-decoration: underline;
}

a:hover, a:active {
  color: #205493;
}

a:visited {
  color: #4c2c92;
}

a:focus {
  box-shadow: 0 0 3px #3e94cf, 0 0 7px #3e94cf;
  outline: 0;
}

.usa-external_link::after {
  background: url("../img/external-link.png") no-repeat 0 0;
  background: url("../img/external-link.svg") no-repeat 0 0;
  background-size: 100%;
  content: '';
  display: inline-block;
  height: 0.65em;
  margin-bottom: -1px;
  margin-left: 4px;
  width: 0.65em;
}

.usa-external_link:hover::after {
  background-image: url("../img/external-link-hover.png");
  background-image: url("../img/external-link-hover.svg");
}

.usa-external_link-alt::after {
  background: url("../img/external-link-alt.png") no-repeat 0 0;
  background: url("../img/external-link-alt.svg") no-repeat 0 0;
  background-size: 100%;
  content: '';
  display: inline-block;
  height: 0.65em;
  margin-bottom: -1px;
  margin-left: 4px;
  width: 0.65em;
}

.usa-external_link-alt:hover::after {
  background-image: url("../img/external-link-alt-hover.png");
  background-image: url("../img/external-link-alt-hover.svg");
}

h1,
h2,
h3,
h4,
h5,
h6 {
  clear: both;
  font-family: "Merriweather", "Georgia", "Cambria", "Times New Roman", "Times", serif;
  line-height: 1.3;
  margin-bottom: .5em;
  margin-top: 1.5em;
}

h1 {
  font-size: 4rem;
  font-weight: 700;
}

h2 {
  font-size: 3rem;
  font-weight: 700;
}

h3 {
  font-size: 2rem;
  font-weight: 700;
}

h4 {
  font-size: 1.7rem;
  font-weight: 700;
}

h5 {
  font-size: 1.5rem;
  font-weight: 700;
}

h6 {
  font-family: "Source Sans Pro", "Helvetica Neue", "Helvetica", "Roboto", "Arial", sans-serif;
  font-size: 1.3rem;
  font-weight: 400;
  text-transform: uppercase;
}

cite,
var,
address,
dfn {
  font-style: normal;
}

.usa-content p:not(.usa-font-lead) {
  max-width: 53rem;
}

.usa-content-list {
  max-width: 53rem;
}

.usa-sans p,
.usa-sans a,
.usa-sans li,
.usa-sans span {
  font-family: "Source Sans Pro", "Helvetica Neue", "Helvetica", "Roboto", "Arial", sans-serif;
}

.usa-sans a {
  border-bottom: none;
  font-weight: 700;
}

.usa-serif p,
.usa-serif a,
.usa-serif li,
.usa-serif span {
  font-family: "Merriweather", "Georgia", "Cambria", "Times New Roman", "Times", serif;
}

.usa-display {
  font-size: 2rem;
  font-weight: 700;
  margin-bottom: 0;
}

@media screen and (min-width: 481px) {
  .usa-display {
    font-size: 4rem;
    font-weight: 700;
  }
}

@media screen and (min-width: 600px) {
  .usa-display {
    font-size: 5.2rem;
    font-weight: 700;
  }
}

.usa-font-lead {
  font-family: "Merriweather", "Georgia", "Cambria", "Times New Roman", "Times", serif;
  font-size: 2rem;
  line-height: 1.7;
  max-width: 77rem;
}

.usa-image-block {
  position: relative;
}

.usa-image-text-block {
  color: #ffffff;
  left: 0;
  margin-left: 8%;
  position: absolute;
  top: 0;
}

.usa-image-text {
  margin-top: 0;
}

.usa-drop_text {
  margin-bottom: 0;
}

.usa-background-dark {
  background-color: #323a45;
}

.usa-background-dark p,
.usa-background-dark span {
  color: #ffffff;
}

.usa-background-dark a {
  color: #d6d7d9;
}

.usa-background-dark a:hover {
  color: #ffffff;
}

.usa-text-small {
  font-size: 1.3rem;
  margin-top: 0;
}

.usa-section > :first-child,
.usa-grid > :first-child,
.usa-grid-full > :first-child {
  margin-top: 0;
}

.usa-section > :last-child,
.usa-grid > :last-child,
.usa-grid-full > :last-child {
  margin-bottom: 0;
}

.usa-width-one-whole:first-child > :first-child,
.usa-width-one-half:first-child > :first-child,
.usa-width-one-third:first-child > :first-child,
.usa-width-two-thirds:first-child > :first-child,
.usa-width-one-fourth:first-child > :first-child,
.usa-width-three-fourths:first-child > :first-child,
.usa-width-one-sixth:first-child > :first-child,
.usa-width-five-sixths:first-child > :first-child,
.usa-width-one-twelfth:first-child > :first-child {
  margin-top: 0;
}

@media screen and (min-width: 600px) {
  .usa-width-one-whole > :first-child,
  .usa-width-one-half > :first-child,
  .usa-width-one-third > :first-child,
  .usa-width-two-thirds > :first-child,
  .usa-width-one-fourth > :first-child,
  .usa-width-three-fourths > :first-child,
  .usa-width-one-sixth > :first-child,
  .usa-width-five-sixths > :first-child,
  .usa-width-one-twelfth > :first-child {
    margin-top: 0;
  }
}

.usa-width-one-whole:last-child > :last-child,
.usa-width-one-half:last-child > :last-child,
.usa-width-one-third:last-child > :last-child,
.usa-width-two-thirds:last-child > :last-child,
.usa-width-one-fourth:last-child > :last-child,
.usa-width-three-fourths:last-child > :last-child,
.usa-width-one-sixth:last-child > :last-child,
.usa-width-five-sixths:last-child > :last-child,
.usa-width-one-twelfth:last-child > :last-child {
  margin-bottom: 0;
}

@media screen and (min-width: 600px) {
  .usa-width-one-whole > :last-child,
  .usa-width-one-half > :last-child,
  .usa-width-one-third > :last-child,
  .usa-width-two-thirds > :last-child,
  .usa-width-one-fourth > :last-child,
  .usa-width-three-fourths > :last-child,
  .usa-width-one-sixth > :last-child,
  .usa-width-five-sixths > :last-child,
  .usa-width-one-twelfth > :last-child {
    margin-bottom: 0;
  }
}

.usa-accordion,
.usa-accordion-bordered {
  margin-top: 0;
  margin-bottom: 0;
  list-style-type: none;
  padding-left: 0;
  color: #212121;
  margin: 0;
  padding: 0;
  width: 100%;
}

.usa-accordion > li,
.usa-accordion-bordered > li {
  margin-bottom: 0;
}

.usa-accordion > ul li ul,
.usa-accordion-bordered > ul li ul {
  list-style: disc;
}

.usa-accordion > ul li ul > li > ul,
.usa-accordion-bordered > ul li ul > li > ul {
  list-style: circle;
}

.usa-accordion > ul li ul > li > ul > li > ul,
.usa-accordion-bordered > ul li ul > li > ul > li > ul {
  list-style: square;
}

.usa-accordion + .usa-accordion,
.usa-accordion + .usa-accordion-bordered,
.usa-accordion-bordered + .usa-accordion,
.usa-accordion-bordered + .usa-accordion-bordered {
  margin-top: 1rem;
}

.usa-accordion > ul,
.usa-accordion-bordered > ul {
  margin-top: 0;
  margin-bottom: 0;
  list-style-type: none;
  padding-left: 0;
  color: #212121;
  margin: 0;
  padding: 0;
  width: 100%;
}

.usa-accordion > ul > li,
.usa-accordion-bordered > ul > li {
  margin-bottom: 0;
}

.usa-accordion > ul > li,
.usa-accordion-bordered > ul > li {
  background-color: #f1f1f1;
  font-family: "Source Sans Pro", "Helvetica Neue", "Helvetica", "Roboto", "Arial", sans-serif;
  list-style: none;
  margin-bottom: 6px;
  width: 100%;
}

.usa-accordion > ul button,
.usa-accordion-bordered > ul button {
  background-color: transparent;
  border: 0;
  border-radius: 0;
  font-weight: 400;
  margin: 0;
  outline: 0;
  padding: 0;
  text-align: left;
  -webkit-font-smoothing: auto;
  background-color: #f1f1f1;
  background-image: url("../img/minus.png");
  background-image: url("../img/minus.svg");
  background-position: right 3rem center;
  background-repeat: no-repeat;
  background-size: 13px;
  color: #212121;
  cursor: pointer;
  display: inline-block;
  font-family: "Source Sans Pro", "Helvetica Neue", "Helvetica", "Roboto", "Arial", sans-serif;
  font-weight: 700;
  margin: 0;
  padding: 1.5rem 5.5rem 1.5rem 3rem;
  width: 100%;
}

.usa-accordion > ul button:hover,
.usa-accordion-bordered > ul button:hover {
  background-color: transparent;
}

.usa-accordion > ul button:focus,
.usa-accordion-bordered > ul button:focus {
  box-shadow: 0 0 3px #3e94cf, 0 0 7px #3e94cf;
}

.usa-accordion > ul button:hover,
.usa-accordion-bordered > ul button:hover {
  background-color: #d6d7d9;
  color: #212121;
}

.usa-accordion > ul button h1,
.usa-accordion > ul button h2,
.usa-accordion > ul button h3,
.usa-accordion > ul button h4,
.usa-accordion > ul button h5,
.usa-accordion > ul button h6,
.usa-accordion-bordered > ul button h1,
.usa-accordion-bordered > ul button h2,
.usa-accordion-bordered > ul button h3,
.usa-accordion-bordered > ul button h4,
.usa-accordion-bordered > ul button h5,
.usa-accordion-bordered > ul button h6 {
  margin: 0;
}

.usa-accordion > ul [aria-expanded=false],
.usa-accordion-bordered > ul [aria-expanded=false] {
  background-image: url("../img/plus.png");
  background-image: url("../img/plus.svg");
  background-repeat: no-repeat;
  background-size: 1.3rem;
}

.usa-accordion > li,
.usa-accordion-bordered > li {
  background-color: #f1f1f1;
  font-family: "Source Sans Pro", "Helvetica Neue", "Helvetica", "Roboto", "Arial", sans-serif;
  list-style: none;
  margin-bottom: 6px;
  width: 100%;
}

.usa-accordion-bordered .usa-accordion-content {
  border-bottom: 3px solid #f1f1f1;
  border-left: 3px solid #f1f1f1;
  border-right: 3px solid #f1f1f1;
}

.usa-accordion-content {
  background-color: #ffffff;
  overflow: auto;
  padding: 3rem;
}

.usa-accordion-content > *:first-child {
  margin-top: 0;
}

.usa-accordion-content > *:last-child {
  margin-bottom: 0;
}

.usa-accordion-content:not([aria-hidden]) {
  position: absolute;
  left: -999em;
}

.usa-accordion-content[aria-hidden=true] {
  display: none;
}

.usa-accordion-button {
  background-color: transparent;
  border: 0;
  border-radius: 0;
  font-weight: 400;
  margin: 0;
  outline: 0;
  padding: 0;
  text-align: left;
  -webkit-font-smoothing: auto;
  background-color: #f1f1f1;
  background-image: url("../img/minus.png");
  background-image: url("../img/minus.svg");
  background-position: right 3rem center;
  background-repeat: no-repeat;
  background-size: 13px;
  color: #212121;
  cursor: pointer;
  display: inline-block;
  font-family: "Source Sans Pro", "Helvetica Neue", "Helvetica", "Roboto", "Arial", sans-serif;
  font-weight: 700;
  margin: 0;
  padding: 1.5rem 5.5rem 1.5rem 3rem;
  width: 100%;
}

.usa-accordion-button:hover {
  background-color: transparent;
}

.usa-accordion-button:focus {
  box-shadow: 0 0 3px #3e94cf, 0 0 7px #3e94cf;
}

.usa-accordion-button:hover {
  background-color: #d6d7d9;
  color: #212121;
}

.usa-accordion-button h1,
.usa-accordion-button h2,
.usa-accordion-button h3,
.usa-accordion-button h4,
.usa-accordion-button h5,
.usa-accordion-button h6 {
  margin: 0;
}

.usa-accordion-button[aria-expanded=false] {
  background-image: url("../img/plus.png");
  background-image: url("../img/plus.svg");
  background-repeat: no-repeat;
  background-size: 1.3rem;
}

.usa-alert {
  background-color: #f1f1f1;
  background-position: 1rem 2rem;
  background-repeat: no-repeat;
  background-size: 4rem;
  margin-top: 1.5em;
  padding: 1em;
}

@media screen and (min-width: 600px) {
  .usa-alert {
    background-size: 5.2rem;
  }
}

.usa-alert ul {
  margin-bottom: 0;
  margin-top: 1em;
}

.usa-alert-icon {
  display: table-cell;
  padding-right: 1rem;
}

.usa-alert-body {
  display: table-cell;
  padding-left: 3.5rem;
  vertical-align: top;
}

@media screen and (min-width: 600px) {
  .usa-alert-body {
    padding-left: 5rem;
  }
}

.usa-alert-body p:first-child {
  margin-top: 0.8rem;
}

.usa-alert-heading {
  margin-bottom: .3rem;
  margin-top: 0;
}

@media screen and (min-width: 600px) {
  .usa-alert-heading {
    margin-top: .3rem;
  }
}

.usa-alert-text {
  font-family: "Source Sans Pro", "Helvetica Neue", "Helvetica", "Roboto", "Arial", sans-serif;
  margin-bottom: 0;
  margin-top: 0;
}

.usa-alert-success {
  background-color: #e7f4e4;
  background-image: url("../img/alerts/success.png");
  background-image: url("../img/alerts/success.svg");
}

.usa-alert-warning {
  background-color: #fff1d2;
  background-image: url("../img/alerts/warning.png");
  background-image: url("../img/alerts/warning.svg");
}

.usa-alert-error {
  background-color: #f9dede;
  background-image: url("../img/alerts/error.png");
  background-image: url("../img/alerts/error.svg");
}

.usa-alert-info {
  background-color: #e1f3f8;
  background-image: url("../img/alerts/info.png");
  background-image: url("../img/alerts/info.svg");
}

.usa-alert-no_icon {
  background-image: none;
}

.usa-banner {
  background-color: #f1f1f1;
  padding-bottom: 0.7rem;
}

@media screen and (min-width: 481px) {
  .usa-banner {
    font-size: 1.3rem;
    padding-bottom: 0;
  }
}

.usa-banner-content {
  padding-right: 1.5rem;
  padding-bottom: 3px;
  padding-left: 1.5rem;
  background-color: transparent;
  font-size: 1.5rem;
  padding-top: 2rem;
  width: 100%;
}

@media screen and (min-width: 600px) {
  .usa-banner-content {
    padding-bottom: 2.3rem;
    padding-top: 4rem;
  }
}

@media screen and (min-width: 951px) {
  .usa-banner-content {
    padding-right: 3rem;
    padding-left: 3rem;
  }
}

.usa-banner-content p:first-child {
  margin-top: 1rem;
}

@media screen and (min-width: 600px) {
  .usa-banner-content p:first-child {
    margin-top: 0;
  }
}

.usa-banner-inner {
  max-width: 1200px;
  margin-left: auto;
  margin-right: auto;
  padding-right: 1.5rem;
  padding-left: 1.5rem;
  max-width: 1040px;
}

.usa-banner-inner::after {
  clear: both;
  content: "";
  display: block;
}

@media screen and (min-width: 951px) {
  .usa-banner-inner {
    padding-right: 3rem;
    padding-left: 3rem;
  }
}

.usa-banner-header {
  padding-top: 0.55rem;
  padding-bottom: 0.55rem;
  font-size: 1.2rem;
  font-weight: 400;
}

@media screen and (min-width: 481px) {
  .usa-banner-header {
    padding-top: 0;
    padding-bottom: 0;
  }
}

.usa-banner-header p {
  margin-top: 0;
  margin-bottom: 0;
  display: inline;
  overflow: hidden;
  vertical-align: middle;
}

@media screen and (min-width: 481px) {
  .usa-banner-header p {
    margin-top: 2px;
    margin-bottom: 2px;
    display: inline-block;
  }
}

.usa-banner-header img {
  float: left;
  margin-right: 1rem;
  margin-top: 1px;
  width: 2.4rem;
}

@media screen and (min-width: 481px) {
  .usa-banner-header img {
    margin-right: 0.7rem;
    width: 2rem;
  }
}

.usa-banner-header-expanded {
  -webkit-box-align: center;
  -ms-flex-align: center;
  align-items: center;
  border-bottom: 1px solid #aeb0b5;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  font-size: 1.5rem;
  min-height: 5.6rem;
  padding-right: 3rem;
}

@media screen and (min-width: 481px) {
  .usa-banner-header-expanded {
    border-bottom: none;
    display: block;
    font-size: 1.2rem;
    font-weight: 400;
    min-height: 0;
    padding-right: 0;
  }
}

.usa-banner-header-expanded > .usa-banner-inner {
  margin-left: 0;
}

@media screen and (min-width: 481px) {
  .usa-banner-header-expanded > .usa-banner-inner {
    margin-left: auto;
  }
}

.usa-banner-header-expanded img {
  margin-right: 2.4rem;
}

@media screen and (min-width: 481px) {
  .usa-banner-header-expanded img {
    margin-right: 0.7rem;
  }
}

.usa-banner-header-expanded p {
  line-height: 1.3;
  vertical-align: top;
}

@media screen and (min-width: 481px) {
  .usa-banner-header-expanded p {
    line-height: 1.5;
    vertical-align: middle;
  }
}

.usa-banner-button {
  background-color: transparent;
  border: 0;
  border-radius: 0;
  font-weight: 400;
  margin: 0;
  outline: 0;
  padding: 0;
  text-align: left;
  -webkit-font-smoothing: auto;
  padding-top: 1.3rem;
  padding-left: 4.8rem;
  background-position-x: right;
  color: #0071bc;
  display: block;
  font-size: 1.2rem;
  height: 4.3rem;
  left: 0;
  position: absolute;
  text-decoration: underline;
  top: 0;
  width: 100%;
}

.usa-banner-button:hover {
  background-color: transparent;
}

@media screen and (min-width: 481px) {
  .usa-banner-button {
    padding-top: 0;
    padding-left: 0;
    /* stylelint-disable declaration-block-no-ignored-properties */
    display: inline;
    height: initial;
    margin-left: 3px;
    position: relative;
    vertical-align: middle;
    width: initial;
    /* stylelint-enable */
  }
}

.usa-banner-button:hover {
  color: #205493;
  text-decoration: underline;
}

.usa-banner-button[aria-expanded=false] {
  background-image: none;
}

.usa-banner-button[aria-expanded=false]::after {
  background-image: url(../img/angle-arrow-down-primary.png);
  background-image: url(../img/angle-arrow-down-primary.svg);
  background-size: 100%;
  content: '';
  display: inline-block;
  height: 1rem;
  width: 1rem;
  /* stylelint-disable block-closing-brace-newline-after, at-rule-empty-line-before */
  margin-left: 0;
  /* stylelint-enable */
}

.usa-banner-button[aria-expanded=false]:hover::after {
  background-image: url(../img/angle-arrow-down-primary-hover.png);
  background-image: url(../img/angle-arrow-down-primary-hover.svg);
}

.usa-banner-button[aria-expanded=false]::after {
  background-position-y: 1px;
}

.usa-banner-button[aria-expanded=true] {
  background-image: none;
  height: 5.6rem;
}

.usa-banner-button[aria-expanded=true]::after {
  background-image: url(../img/close.png);
  background-image: url(../img/close.svg);
  background-size: 100%;
  content: '';
  display: inline-block;
  height: 1.3rem;
  width: 1.3rem;
  /* stylelint-disable block-closing-brace-newline-after, at-rule-empty-line-before */
  margin-left: 0;
  /* stylelint-enable */
}

@media screen and (min-width: 481px) {
  .usa-banner-button[aria-expanded=true] {
    height: initial;
    padding: 0;
    position: relative;
  }
  .usa-banner-button[aria-expanded=true]::after {
    background-image: url(../img/angle-arrow-up-primary.png);
    background-image: url(../img/angle-arrow-up-primary.svg);
    background-size: 100%;
    content: '';
    display: inline-block;
    height: 1rem;
    width: 1rem;
    /* stylelint-disable block-closing-brace-newline-after, at-rule-empty-line-before */
    margin-left: 0;
    /* stylelint-enable */
  }
  .usa-banner-button[aria-expanded=true]:hover::after {
    background-image: url(../img/angle-arrow-up-primary-hover.png);
    background-image: url(../img/angle-arrow-up-primary-hover.svg);
  }
  .usa-banner-button[aria-expanded=true]::after {
    background-position-y: 1px;
  }
}

.usa-banner-button[aria-expanded=true]::after {
  position: absolute;
  right: 1.5rem;
  top: 2.15rem;
}

@media screen and (min-width: 481px) {
  .usa-banner-button[aria-expanded=true]::after {
    position: static;
  }
}

.usa-banner-button[aria-expanded=true] .usa-banner-button-text {
  display: none;
}

@media screen and (min-width: 481px) {
  .usa-banner-button[aria-expanded=true] .usa-banner-button-text {
    display: inline;
  }
}

.usa-banner-icon {
  width: 3.8rem;
}

.usa-footer .usa-unstyled-list {
  display: block;
}

.usa-footer .usa-footer-primary-link {
  color: #212121;
  display: block;
  font-weight: 700;
  margin-top: 0;
  padding-bottom: 2rem;
  padding-top: 2rem;
  text-decoration: none;
}

@media screen and (min-width: 600px) {
  .usa-footer .usa-footer-primary-link {
    border-top: none;
  }
}

.usa-footer .usa-footer-primary-link:hover {
  text-decoration: underline;
}

.usa-footer a {
  font-weight: normal;
}

.usa-footer-return-to-top {
  padding-bottom: 2rem;
  padding-top: 2rem;
}

.usa-footer-primary-section {
  background-color: #f1f1f1;
}

.usa-footer-primary-section .usa-footer-primary-content {
  padding-left: 2.5rem;
  padding-right: 2.5rem;
}

@media screen and (min-width: 600px) {
  .usa-footer-primary-section .usa-footer-primary-content {
    padding-left: 0;
    padding-right: 0;
  }
}

.usa-footer-primary-section .usa-footer-primary-content li {
  margin-left: 1rem;
}

@media screen and (min-width: 600px) {
  .usa-footer-primary-section .usa-footer-primary-content li {
    margin-left: 0;
  }
}

@media screen and (min-width: 600px) {
  .usa-footer-primary-section .usa-grid-full {
    padding-left: 2.5rem;
    padding-right: 2.5rem;
  }
}

.usa-footer-medium .usa-footer-primary-section {
  padding: 0;
}

@media screen and (min-width: 600px) {
  .usa-footer-medium .usa-footer-primary-section {
    padding-bottom: 1rem;
    padding-top: 1rem;
  }
}

@media screen and (min-width: 1201px) {
  .usa-footer-medium .usa-footer-primary-section .usa-footer-primary-content {
    margin-right: 6%;
    width: inherit;
  }
}

@media screen and (min-width: 1201px) {
  .usa-footer-medium .usa-footer-primary-section .usa-footer-primary-content:last-child {
    margin-right: 0;
  }
}

@media screen and (min-width: 600px) {
  .usa-footer-medium .usa-footer-nav ul {
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
  }
}

.usa-footer-slim .usa-footer-nav a {
  display: block;
}

@media screen and (min-width: 1201px) {
  .usa-footer-slim .usa-footer-nav .usa-footer-primary-content {
    margin-right: 9%;
    width: inherit;
  }
}

@media screen and (min-width: 1201px) {
  .usa-footer-slim .usa-footer-nav .usa-footer-primary-content:last-child {
    margin-right: 0;
  }
}

.usa-footer-slim .usa-footer-primary-section {
  padding-bottom: 2rem;
}

@media screen and (min-width: 600px) {
  .usa-footer-slim .usa-footer-primary-section {
    padding-bottom: 1rem;
    padding-top: 1rem;
  }
  .usa-footer-slim .usa-footer-primary-section .usa-grid-full {
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
  }
}

@media screen and (min-width: 600px) {
  .usa-footer-slim .usa-footer-contact_info > * {
    margin: 0;
  }
}

@media screen and (min-width: 600px) {
  .usa-footer-slim .usa-footer-contact_info {
    padding-top: 2rem;
    padding-bottom: 2rem;
  }
}

@media screen and (min-width: 600px) {
  .usa-footer-slim .usa-footer-contact_info {
    width: 100%;
  }
}

@media screen and (min-width: 1201px) {
  .usa-footer-slim .usa-footer-contact_info {
    float: left;
    display: block;
    margin-right: 2.35765%;
    width: 48.82117%;
  }
  .usa-footer-slim .usa-footer-contact_info:last-child {
    margin-right: 0;
  }
}

/* stylelint-disable selector-no-qualifying-type */
ul.usa-footer-primary-content,
li.usa-footer-primary-content,
li.usa-footer-primary-content {
  border-top: 1px solid #212121;
}

@media screen and (min-width: 600px) {
  ul.usa-footer-primary-content,
  li.usa-footer-primary-content,
  li.usa-footer-primary-content {
    border: none;
  }
}

ul.usa-footer-primary-content:last-child,
li.usa-footer-primary-content:last-child,
li.usa-footer-primary-content:last-child {
  border-bottom: 1px solid #212121;
}

@media screen and (min-width: 600px) {
  ul.usa-footer-primary-content:last-child,
  li.usa-footer-primary-content:last-child,
  li.usa-footer-primary-content:last-child {
    border-bottom: none;
  }
}

/* stylelint-enable */
.usa-sign_up-block {
  padding-bottom: 2rem;
  padding-left: 2.5rem;
  padding-right: 2.5rem;
}

@media screen and (min-width: 600px) {
  .usa-sign_up-block {
    float: right;
    padding: 0;
  }
}

.usa-sign_up-block label:first-of-type {
  margin-top: 0;
}

.usa-sign_up-block button {
  float: none;
  margin-right: 0;
  margin-top: 1.5rem;
}

.usa-sign_up-block input {
  width: 100%;
}

.usa-footer-secondary_section {
  background-color: #d6d7d9;
  padding-bottom: 3rem;
  padding-top: 3rem;
}

.usa-footer-secondary_section a {
  color: #212121;
}

@media screen and (min-width: 600px) {
  .usa-footer-big-secondary-section {
    padding-top: 5rem;
  }
}

@media screen and (min-width: 600px) {
  .usa-footer-contact-links {
    text-align: right;
  }
}

.usa-social-links a {
  text-decoration: none;
}

@media screen and (min-width: 600px) {
  .usa-footer-big .usa-footer-primary-section {
    padding-bottom: 4rem;
    padding-top: 3rem;
  }
}

.usa-footer-big ul {
  padding-bottom: 2.5rem;
}

@media screen and (min-width: 600px) {
  .usa-footer-big ul {
    padding-bottom: 0;
  }
}

.usa-footer-big ul:last-child {
  border-bottom: 1px solid #212121;
}

@media screen and (min-width: 600px) {
  .usa-footer-big ul:last-child {
    border-bottom: none;
  }
}

.usa-footer-big ul li {
  line-height: 2em;
}

.usa-footer-big ul .usa-footer-primary-link {
  background-image: url("../img/arrow-down.png");
  background-image: url("../img/arrow-down.svg");
  background-position: 1.5rem center;
  background-repeat: no-repeat;
  background-size: 1.3rem;
  margin-left: 0;
  padding-left: 3.5rem;
}

@media screen and (min-width: 600px) {
  .usa-footer-big ul .usa-footer-primary-link {
    background: none;
    margin-bottom: .8rem;
    padding-bottom: 0;
    padding-left: 0;
  }
}

.usa-footer-big ul .usa-footer-primary-link > * {
  margin-top: 0;
  margin-bottom: 0;
}

.usa-footer-big ul.hidden {
  /* stylelint-disable-line selector-no-qualifying-type */
  padding-bottom: 0;
}

.usa-footer-big ul.hidden li {
  display: none;
}

.usa-footer-big ul.hidden .usa-footer-primary-link {
  /* stylelint-disable-line selector-no-qualifying-type */
  background-image: url("../img/arrow-right.png");
  background-image: url("../img/arrow-right.svg");
  cursor: pointer;
  display: block;
}

@media screen and (min-width: 600px) {
  .usa-footer-big ul.hidden .usa-footer-primary-link {
    background: none;
    padding-left: 0;
  }
}

.usa-footer-topic {
  margin: 0;
  padding: 2rem 0;
}

@media screen and (min-width: 600px) {
  .usa-sign_up-header {
    margin: 0;
    padding: 2rem 0;
  }
}

.usa-footer-logo-img {
  max-width: 14rem;
}

.usa-footer-slim-logo-img {
  float: left;
  max-width: 10rem;
}

.usa-footer-logo-heading {
  margin-top: 2rem;
}

.usa-footer-contact-heading {
  margin-top: 0;
}

@media screen and (min-width: 600px) {
  .usa-footer-contact-heading {
    margin-top: 1rem;
  }
}

.usa-footer-slim-logo-heading {
  display: block;
  padding-top: 1rem;
}

@media screen and (min-width: 600px) {
  .usa-footer-slim-logo-heading {
    display: inline-block;
    padding-left: 1em;
  }
}

.usa-social_link, .usa-link-facebook, .usa-link-twitter, .usa-link-youtube, .usa-link-rss {
  margin: 2.5rem 1rem 1.5rem 0;
  background-position: center center;
  background-repeat: no-repeat;
  background-size: auto 3rem;
  display: inline-block;
  height: 4.4rem;
  left: -1.6rem;
  position: relative;
  text-align: center;
  width: 4.4rem;
}

@media screen and (min-width: 600px) {
  .usa-social_link, .usa-link-facebook, .usa-link-twitter, .usa-link-youtube, .usa-link-rss {
    margin: 0 0 0 1rem;
    left: 1.2rem;
  }
}

.usa-social_link span, .usa-link-facebook span, .usa-link-twitter span, .usa-link-youtube span, .usa-link-rss span {
  position: absolute;
  left: -999em;
}

.usa-link-facebook {
  background-image: url("../img/social-icons/png/facebook25.png");
  background-image: url("../img/social-icons/svg/facebook25.svg");
}

.usa-link-twitter {
  background-image: url("../img/social-icons/png/twitter16.png");
  background-image: url("../img/social-icons/svg/twitter16.svg");
}

.usa-link-youtube {
  background-image: url("../img/social-icons/png/youtube15.png");
  background-image: url("../img/social-icons/svg/youtube15.svg");
}

.usa-link-rss {
  background-image: url("../img/social-icons/png/rss25.png");
  background-image: url("../img/social-icons/svg/rss25.svg");
}

form a {
  border-bottom: 0;
}

form [type=submit],
form [type=submit] {
  display: block;
  margin-bottom: 1.5em;
  margin-top: 2.5rem;
}

@media screen and (min-width: 600px) {
  form [type=submit],
  form [type=submit] {
    padding-left: 2.7em;
    padding-right: 2.7em;
    width: auto;
  }
}

form [name=password],
form [name=confirmPassword] {
  margin-bottom: 1.1rem;
}

@media screen and (min-width: 600px) {
  .usa-form {
    max-width: 32rem;
  }
}

.usa-form-note {
  float: right;
  font-family: "Source Sans Pro", "Helvetica Neue", "Helvetica", "Roboto", "Arial", sans-serif;
  font-size: 1.5rem;
  margin: 0 0 1.5rem;
}

.usa-form-note + * {
  clear: both;
}

fieldset {
  border: none;
  margin: 0;
  padding: 0;
}

@media screen and (min-width: 600px) {
  .usa-form-large {
    max-width: 46rem;
  }
}

input.usa-input-tiny {
  /* stylelint-disable-line selector-no-qualifying-type */
}

@media screen and (min-width: 600px) {
  input.usa-input-tiny {
    max-width: 6rem;
  }
}

input.usa-input-medium {
  /* stylelint-disable-line selector-no-qualifying-type */
}

@media screen and (min-width: 600px) {
  input.usa-input-medium {
    max-width: 12rem;
  }
}

@media screen and (min-width: 600px) {
  .usa-input-grid {
    padding-right: 5%;
  }
}

@media screen and (min-width: 600px) {
  .usa-input-grid:last-of-type {
    padding-right: 0;
  }
}

@media screen and (min-width: 600px) {
  .usa-input-grid-small {
    float: left;
    width: 35%;
  }
}

.usa-input-grid-small input {
  margin-bottom: 3rem;
}

.usa-input-grid-small select {
  margin-bottom: 3rem;
}

@media screen and (min-width: 600px) {
  .usa-input-grid-medium {
    float: left;
    width: 65%;
  }
}

.usa-input-grid-medium input {
  margin-bottom: 3rem;
}

.usa-input-grid-medium select {
  margin-bottom: 3rem;
}

@media screen and (min-width: 600px) {
  .usa-input-grid-large {
    float: left;
    width: 100%;
  }
}

.usa-input-grid-large input {
  margin-bottom: 3rem;
}

.usa-input-grid-large select {
  margin-bottom: 3rem;
}

.usa-additional_text {
  font-weight: normal;
}

.usa-checklist {
  list-style: none;
  margin-left: 0;
  padding-left: 0;
}

.usa-checklist li {
  display: inline-block;
  list-style: none;
  margin-bottom: 0;
  margin-top: 0;
  padding-left: 3em;
  text-indent: -2em;
}

.usa-checklist li::before {
  content: ' ';
  display: inline-block;
  height: .8em;
  margin-right: .2em;
  width: 1.8em;
}

.usa-checklist-checked::before {
  background-image: url("../img/correct9.png");
  background-image: url("../img/correct9.svg");
  background-position: 100%;
  background-repeat: no-repeat;
  background-size: 100%;
}

.usa-graphic_list .usa-graphic_list-row .usa-media_block {
  margin-bottom: 3rem;
}

@media screen and (min-width: 600px) {
  .usa-graphic_list .usa-graphic_list-row .usa-media_block {
    margin-bottom: 6rem;
  }
}

@media screen and (min-width: 600px) {
  .usa-graphic_list .usa-graphic_list-row:last-child .usa-media_block {
    margin-bottom: 0;
  }
}

.usa-graphic_list .usa-graphic_list-row:last-child .usa-media_block:last-child {
  margin-bottom: 0;
}

.usa-graphic_list .usa-media_block-img {
  margin-right: 3rem;
}

.usa-graphic_list .usa-media_block-body > :first-child {
  margin-top: 0;
}

.usa-header {
  width: 100%;
  z-index: 7000;
}

@media screen and (min-width: 951px) {
  .usa-header {
    border-bottom: 1px solid #aeb0b5;
  }
}

.usa-header a {
  border-bottom: none;
}

.usa-header .usa-search {
  margin-bottom: 1.5rem;
}

@media screen and (min-width: 951px) {
  .usa-header .usa-search {
    float: right;
    margin-bottom: 0;
    max-width: 21.5rem;
  }
}

.usa-logo {
  float: left;
  line-height: 4rem;
  margin-left: 1.5rem;
}

@media screen and (min-width: 951px) {
  .usa-logo {
    line-height: 7.5rem;
    margin-left: 0;
  }
}

.usa-logo a {
  color: #212121;
  text-decoration: none;
}

.usa-logo br {
  display: none;
}

@media screen and (min-width: 951px) {
  .usa-logo br {
    display: block;
  }
}

.usa-logo-text {
  display: block;
  font-size: 1.5rem;
  font-style: normal;
  font-weight: 700;
  margin: 0;
}

@media screen and (min-width: 951px) {
  .usa-logo-text {
    display: block;
    font-size: 2.4rem;
    line-height: 1.3;
  }
}

.usa-menu-btn {
  /* stylelint-disable declaration-block-no-ignored-properties */
  background-color: transparent;
  border: 0;
  border-radius: 0;
  font-weight: 400;
  margin: 0;
  outline: 0;
  padding: 0;
  text-align: left;
  -webkit-font-smoothing: auto;
  background-color: #0071bc;
  color: #ffffff;
  display: inline;
  float: right;
  font-size: 1.3rem;
  height: 4rem;
  line-height: 4rem;
  text-align: center;
  text-decoration: none;
  text-transform: uppercase;
  width: 5.8rem;
  /* stylelint-enable */
}

.usa-menu-btn:hover {
  background-color: transparent;
}

@media screen and (min-width: 951px) {
  .usa-menu-btn {
    display: none;
  }
}

.usa-menu-btn:hover {
  color: #ffffff;
  background-color: #205493;
}

.usa-menu-btn:visited {
  color: #ffffff;
}

.usa-overlay {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background: #000000;
  opacity: 0;
  transition: all 0.2s ease-in-out;
  visibility: hidden;
  z-index: 8000;
}

.usa-overlay.is-visible {
  opacity: 0.1;
  visibility: visible;
}

@media screen and (min-width: 951px) {
  .usa-header-basic .usa-logo {
    bottom: 1.9rem;
    position: absolute;
  }
}

@media screen and (min-width: 951px) {
  .usa-header-basic .usa-navbar {
    position: relative;
    width: 18%;
  }
}

@media screen and (min-width: 951px) {
  .usa-header-extended .usa-header {
    border-bottom: none;
  }
}

@media screen and (min-width: 951px) {
  .usa-header-extended .usa-logo {
    margin-top: 3rem;
    margin-bottom: 3rem;
  }
}

@media screen and (min-width: 951px) {
  .usa-header-extended em {
    font-size: 3.2rem;
    line-height: 1;
  }
}

@media screen and (min-width: 951px) {
  .usa-header-extended .usa-navbar {
    max-width: 1200px;
    margin-left: auto;
    margin-right: auto;
    padding-right: 3rem;
    padding-left: 3rem;
    display: block;
    height: auto;
    max-width: 1040px;
  }
  .usa-header-extended .usa-navbar::after {
    clear: both;
    content: "";
    display: block;
  }
}

@media screen and (min-width: 951px) {
  .usa-header-extended .usa-nav {
    border-top: 1px solid #aeb0b5;
    float: none;
    padding: 0;
    width: 100%;
  }
}

@media screen and (min-width: 951px) {
  .usa-header-extended .usa-nav-inner {
    max-width: 1200px;
    margin-left: auto;
    margin-right: auto;
    padding-right: 3rem;
    padding-left: 2rem;
    margin-top: -1px;
    max-width: 1040px;
    position: relative;
  }
  .usa-header-extended .usa-nav-inner::after {
    clear: both;
    content: "";
    display: block;
  }
}

@media screen and (min-width: 951px) {
  .usa-header-extended .usa-nav-primary::after {
    clear: both;
    content: "";
    display: block;
  }
}

.usa-header-extended .usa-nav-primary button[aria-expanded=false], .usa-header-extended .usa-nav-primary button[aria-expanded=true] {
  /* stylelint-disable-line selector-no-qualifying-type */
}

@media screen and (min-width: 951px) {
  .usa-header-extended .usa-nav-primary button[aria-expanded=false], .usa-header-extended .usa-nav-primary button[aria-expanded=true] {
    /* stylelint-disable-line selector-no-qualifying-type */
    background-position: right 1.5rem top 50%;
  }
}

@media screen and (min-width: 951px) {
  .usa-header-extended .usa-nav-link {
    padding-top: 1.9rem;
  }
}

@media screen and (min-width: 951px) {
  .usa-header-extended .usa-nav-submenu .usa-grid-full {
    padding-left: 1.2rem;
  }
}

@media screen and (min-width: 951px) {
  .usa-header-extended .usa-megamenu {
    padding-left: 3rem;
  }
}

.usa-hero {
  padding-top: 3rem;
  padding-bottom: 3rem;
  background-image: url("../img/hero.png");
  background-position: center;
  background-size: cover;
}

.usa-hero .usa-button {
  color: #ffffff;
}

.usa-section-dark .usa-hero-link {
  color: #02bfe7;
}

.usa-hero-callout {
  background-color: #112e51;
  padding: 3rem;
}

@media screen and (min-width: 481px) {
  .usa-hero-callout {
    max-width: 30rem;
  }
}

.usa-hero-callout > *:first-child {
  margin-top: 0;
  margin-bottom: 3rem;
}

.usa-hero-callout .usa-button {
  font-size: 1.4rem;
  margin-top: 7rem;
  width: 100%;
}

.usa-hero-callout-alt {
  color: #ffffff;
  display: block;
}

.usa-layout-docs {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
}

@media screen and (min-width: 1201px) {
  .usa-layout-docs {
    display: inherit;
  }
}

.usa-layout-docs .usa-grid > :first-child:not(.usa-width-*) {
  margin-top: 0;
}

.usa-layout-docs .usa-grid > :last-child:not(.usa-width-*) {
  margin-bottom: 0;
}

.usa-layout-docs-sidenav {
  -webkit-box-ordinal-group: 3;
  -ms-flex-order: 2;
  order: 2;
}

.usa-layout-docs-main_content {
  margin-bottom: 3rem;
  -webkit-box-ordinal-group: 2;
  -ms-flex-order: 1;
  order: 1;
}

@media screen and (min-width: 1201px) {
  .usa-layout-docs-main_content {
    margin-bottom: 0;
  }
}

.usa-layout-docs-main_content > :first-child {
  margin-top: 0;
}

.usa-media_block-img {
  float: left;
  margin-right: 1rem;
}

.usa-media_block-body {
  overflow: hidden;
}

.usa-navbar {
  border-bottom: 1px solid #aeb0b5;
  height: 4rem;
}

@media screen and (min-width: 951px) {
  .usa-navbar {
    border-bottom: none;
    display: inline-block;
    height: 10.3rem;
  }
}

.usa-nav-link {
  -moz-osx-font-smoothing: grayscale;
  -webkit-font-smoothing: antialiased;
}

@media screen and (min-width: 951px) {
  .usa-nav-link:hover span {
    border-bottom: 0.7rem solid #0071bc;
    padding-bottom: 1rem;
  }
}

@media screen and (min-width: 951px) {
  .usa-nav-container {
    max-width: 1200px;
    margin-left: auto;
    margin-right: auto;
    padding-right: 3rem;
    padding-left: 3rem;
    max-width: 1040px;
  }
  .usa-nav-container::after {
    clear: both;
    content: "";
    display: block;
  }
}

.usa-nav {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: auto;
  -webkit-transform: translateX(26rem);
  -ms-transform: translateX(26rem);
  transform: translateX(26rem);
  background: #ffffff;
  border-left: 1px solid #aeb0b5;
  border-right: 0;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
  overflow-y: auto;
  padding: 2rem;
  width: 26rem;
  z-index: 9000;
}

@media screen and (min-width: 951px) {
  .usa-nav {
    padding-top: 5rem;
    padding-right: 0;
    padding-bottom: 0;
    -webkit-transform: translateX(0);
    -ms-transform: translateX(0);
    transform: translateX(0);
    border-left: none;
    display: block;
    float: right;
    overflow-y: visible;
    position: relative;
    width: auto;
  }
}

.usa-nav.is-visible {
  -webkit-transform: translateX(0);
  -ms-transform: translateX(0);
  transform: translateX(0);
  transition: all 0.3s ease-in-out;
}

.usa-nav nav {
  margin-top: 6rem;
  min-height: 100%;
}

@media screen and (min-width: 951px) {
  .usa-nav nav {
    margin-top: 0;
  }
}

.usa-nav .usa-current {
  border-left: 4px solid #0071bc;
  color: #0071bc;
  font-weight: 700;
  padding-left: 1.4rem;
}

.usa-nav .usa-button {
  width: 100%;
}

@media screen and (min-width: 951px) {
  .usa-nav .usa-search {
    margin-left: 1.5rem;
  }
}

.usa-nav-primary {
  margin-top: 0;
  margin-bottom: 0;
  list-style-type: none;
  padding-left: 0;
  -webkit-box-ordinal-group: 3;
  -ms-flex-order: 2;
  order: 2;
}

.usa-nav-primary > li {
  margin-bottom: 0;
}

.usa-nav-primary > li {
  background-color: transparent;
  border-top: 1px solid #5b616b;
  font-size: 1.7rem;
}

.usa-nav-primary > li:first-child {
  border-top: none;
}

.usa-nav-primary a {
  border: none;
  color: #212121;
  display: block;
  font-family: "Source Sans Pro", "Helvetica Neue", "Helvetica", "Roboto", "Arial", sans-serif;
  line-height: 1.3;
  padding: 0.85rem 1rem 0.85rem 1.8rem;
  text-decoration: none;
}

.usa-nav-primary a:hover {
  background-color: #f1f1f1;
  color: #0071bc;
  text-decoration: none;
}

.usa-nav-primary a:focus {
  position: relative;
  z-index: 1;
}

.usa-nav-primary a.usa-current {
  /* stylelint-disable-line selector-no-qualifying-type */
  border-left: 4px solid #0071bc;
  color: #0071bc;
  font-weight: 700;
  padding-left: 1.4rem;
}

@media screen and (min-width: 951px) {
  .usa-nav-primary {
    display: inline;
  }
}

@media screen and (min-width: 951px) {
  .usa-nav-primary li {
    border-top: none;
  }
}

.usa-nav-primary > li {
  width: auto;
}

@media screen and (min-width: 951px) {
  .usa-nav-primary > li {
    display: inline-block;
    margin-left: -4px;
  }
}

@media screen and (min-width: 951px) {
  .usa-nav-primary > li > a {
    padding: 1.3rem 1.5rem 1.7rem;
    color: #5b616b;
    font-size: 1.5rem;
    font-weight: 700;
    line-height: 1.2;
  }
}

@media screen and (min-width: 951px) {
  .usa-nav-primary > li > a:hover {
    background-color: transparent;
  }
}

.usa-nav-primary button {
  background-color: transparent;
  border: 0;
  border-radius: 0;
  font-weight: 400;
  margin: 0;
  outline: 0;
  padding: 0;
  text-align: left;
  -webkit-font-smoothing: auto;
  -moz-osx-font-smoothing: grayscale;
  -webkit-font-smoothing: antialiased;
  font-weight: 400;
  padding: 1.4rem 1.5rem 1rem 1.8rem;
}

.usa-nav-primary button:hover {
  background-color: transparent;
}

@media screen and (min-width: 951px) {
  .usa-nav-primary button {
    padding-right: 3rem;
    padding-bottom: 1.9rem;
    padding-left: 1.5rem;
    color: #5b616b;
    font-size: 1.5rem;
    font-weight: 700;
    width: initial;
  }
}

.usa-nav-primary button:focus, .usa-nav-primary button:active {
  box-shadow: 0 0 3px #3e94cf, 0 0 7px #3e94cf;
}

.usa-nav-primary button:hover {
  background-color: #f1f1f1;
  color: #0071bc;
}

@media screen and (min-width: 951px) {
  .usa-nav-primary button:hover {
    background-color: transparent;
  }
}

.usa-nav-primary button[aria-expanded=false] {
  /* stylelint-disable-line selector-no-qualifying-type */
  background-image: url("../img/plus-alt.png");
  background-image: url("../img/plus-alt.svg");
  background-repeat: no-repeat;
  background-position: right 0 center;
  background-size: 1rem;
}

@media screen and (min-width: 951px) {
  .usa-nav-primary button[aria-expanded=false] {
    background-image: url("../img/angle-arrow-down.png");
    background-image: url("../img/angle-arrow-down.svg");
    background-position: right 1.5rem top 44%;
  }
}

.usa-nav-primary button[aria-expanded=true] {
  /* stylelint-disable-line selector-no-qualifying-type */
  background-image: url("../img/minus-alt.png");
  background-image: url("../img/minus-alt.svg");
  background-repeat: no-repeat;
  background-position: right 0 center;
  background-size: 1rem;
}

@media screen and (min-width: 951px) {
  .usa-nav-primary button[aria-expanded=true] {
    background-color: #112e51;
    color: #ffffff;
    background-image: url("../img/angle-arrow-down-hover.png");
    background-image: url("../img/angle-arrow-down-hover.svg");
    background-position: right 1.5rem top 44%;
  }
  .usa-nav-primary button[aria-expanded=true]:hover {
    background-color: #112e51;
  }
  .usa-nav-primary button[aria-expanded=true] span {
    border-bottom: 0.7rem solid #0071bc;
    padding-bottom: 1rem;
  }
}

@media screen and (min-width: 951px) {
  .usa-nav-primary a.usa-current {
    border-left: 0;
    padding-left: 1rem;
  }
  .usa-nav-primary a.usa-current span {
    border-bottom: 0.7rem solid #0071bc;
    padding-bottom: 1rem;
  }
}

@media screen and (min-width: 951px) {
  .usa-nav-secondary {
    position: absolute;
    right: 3rem;
    top: -5.7rem;
  }
}

.usa-nav-secondary .usa-search {
  margin-top: 3rem;
  margin-bottom: 3rem;
}

@media screen and (min-width: 951px) {
  .usa-nav-secondary .usa-search {
    margin-top: -0.2rem;
    margin-bottom: 0;
    margin-left: 0;
    float: left;
  }
}

@media screen and (min-width: 951px) {
  .usa-nav-secondary-links {
    float: left;
  }
}

@media screen and (min-width: 951px) {
  .usa-nav-secondary-links li {
    display: inline;
    padding-left: 1rem;
  }
}

@media screen and (min-width: 951px) {
  .usa-nav-secondary-links li:not(:last-child)::after {
    content: '|';
    padding-left: 1rem;
  }
}

.usa-nav-secondary-links a,
.usa-nav-secondary-links .usa-header-search-button {
  color: #5b616b;
  display: inline-block;
  font-size: 1.5rem;
  text-decoration: none;
}

.usa-nav-secondary-links a:hover,
.usa-nav-secondary-links .usa-header-search-button:hover {
  color: #0071bc;
}

.usa-nav-secondary-links .usa-header-search-button {
  background-color: transparent;
  border: 0;
  border-radius: 0;
  font-weight: 400;
  margin: 0;
  outline: 0;
  padding: 0;
  text-align: left;
  -webkit-font-smoothing: auto;
  display: none;
}

.usa-nav-secondary-links .usa-header-search-button:hover {
  background-color: transparent;
}

@media screen and (min-width: 951px) {
  .usa-nav-secondary-links .usa-header-search-button {
    background-image: url("../img/search-alt.png");
    background-image: url("../img/search-alt.svg");
    background-repeat: no-repeat;
    background-position: left center;
    background-size: 2.2rem;
    display: inline-block;
    padding-left: 2.3rem;
  }
}

@media screen and (min-width: 951px) {
  .usa-nav-secondary-links .usa-header-search-button.is-hidden {
    display: none;
  }
}

@media screen and (min-width: 951px) {
  .usa-nav-secondary-links a.usa-current {
    border-left: 0;
    padding-left: 0;
  }
}

.usa-nav-submenu {
  margin-top: 0;
  margin-bottom: 0;
  list-style-type: none;
  padding-left: 0;
  margin: 0;
  width: 100%;
}

.usa-nav-submenu > li {
  margin-bottom: 0;
}

.usa-nav-submenu li {
  border: none;
  font-size: 1.5rem;
}

.usa-nav-submenu a {
  padding-left: 2.8rem;
  line-height: 1.3;
}

.usa-nav-submenu a:hover, .usa-nav-submenu a.usa-current {
  /* stylelint-disable-line selector-no-qualifying-type */
  border: none;
  padding-left: 2.8rem;
}

.usa-nav-submenu .usa-sidenav-sub_list a {
  padding-left: 3.8rem;
}

.usa-nav-submenu .usa-sidenav-sub_list a:hover {
  padding-left: 3.8rem;
}

@media screen and (min-width: 951px) {
  .usa-nav-submenu {
    margin-top: 0;
    margin-bottom: 0;
    list-style-type: none;
    padding-left: 0;
    padding-top: 1.15rem;
    padding-bottom: 1.15rem;
    background-color: #112e51;
    min-width: 21.5rem;
    width: auto;
    position: absolute;
  }
  .usa-nav-submenu > li {
    margin-bottom: 0;
  }
}

.usa-nav-submenu[aria-hidden=true] {
  display: none;
}

@media screen and (min-width: 951px) {
  .usa-nav-submenu a {
    color: #ffffff;
    padding-left: 1.8rem;
  }
}

@media screen and (min-width: 951px) {
  .usa-nav-submenu a:hover {
    background-color: #112e51;
    color: #ffffff;
    text-decoration: underline;
  }
}

.usa-nav-submenu a:hover, .usa-nav-submenu a.usa-current {
  /* stylelint-disable-line selector-no-qualifying-type */
}

@media screen and (min-width: 951px) {
  .usa-nav-submenu a:hover, .usa-nav-submenu a.usa-current {
    padding-left: 1.8rem;
  }
}

.usa-nav-submenu li {
  margin-bottom: 0;
}

.usa-nav-close {
  background-color: transparent;
  border: 0;
  border-radius: 0;
  font-weight: 400;
  margin: 0;
  outline: 0;
  padding: 0;
  text-align: left;
  -webkit-font-smoothing: auto;
  margin: -1.2rem -1.5rem 2.4rem auto;
  float: right;
  height: 4.4rem;
  text-align: center;
  width: 4.4rem;
}

.usa-nav-close:hover {
  background-color: transparent;
}

@media screen and (min-width: 951px) {
  .usa-nav-close {
    display: none;
  }
}

.usa-nav-close img {
  width: 1.3rem;
}

.usa-mobile_nav-active {
  overflow: hidden;
}

@media screen and (min-width: 951px) {
  .usa-megamenu {
    padding-top: 3.15rem;
    padding-bottom: 3.15rem;
    left: -1.8rem;
    width: 100%;
  }
}

@media screen and (min-width: 951px) {
  .usa-megamenu::before {
    background-color: #112e51;
    content: '';
    display: block;
    height: 100%;
    position: absolute;
    top: 0;
    width: 1000%;
    right: 100%;
  }
}

@media screen and (min-width: 951px) {
  .usa-megamenu::after {
    background-color: #112e51;
    content: '';
    display: block;
    height: 100%;
    position: absolute;
    top: 0;
    width: 1000%;
    left: 100%;
  }
}

@media screen and (min-width: 951px) {
  .usa-header-basic-megamenu .usa-nav {
    padding-top: 0;
    width: 100%;
  }
}

.usa-header-basic-megamenu .usa-nav-inner {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
}

@media screen and (min-width: 951px) {
  .usa-header-basic-megamenu .usa-nav-inner {
    display: initial;
    float: right;
    margin-top: -4.8rem;
  }
}

@media screen and (min-width: 951px) {
  .usa-header-basic-megamenu .usa-nav-submenu .usa-grid-full {
    margin-left: -1.8rem;
  }
}

@media screen and (min-width: 951px) {
  .usa-megamenu-col {
    float: left;
    display: block;
    margin-right: 2.35765%;
    width: 23.23176%;
  }
  .usa-megamenu-col:last-child {
    margin-right: 0;
  }
  .usa-megamenu-col:nth-child(2n) {
    float: left;
    display: block;
    margin-right: 2.35765%;
    width: 23.23176%;
  }
  .usa-megamenu-col:nth-child(2n):last-child {
    margin-right: 0;
  }
  .usa-megamenu-col:nth-child(4n) {
    margin-right: 0;
  }
}

.usa-megamenu-col > ul {
  margin-top: 0;
  margin-bottom: 0;
  list-style-type: none;
  padding-left: 0;
}

.usa-megamenu-col > ul > li {
  margin-bottom: 0;
}

.usa-search {
  max-width: none;
  position: relative;
}

.usa-search::after {
  clear: both;
  content: "";
  display: block;
}

.usa-search [type=search],
.usa-search .usa-search-input {
  padding-top: 0;
  padding-bottom: 0;
  -webkit-appearance: none;
  border-bottom-right-radius: 0;
  border-right: none;
  border-top-right-radius: 0;
  box-sizing: border-box;
  float: left;
  font-size: 1.4rem;
  height: 3.3rem;
  margin: 0;
  width: calc(100% - 4.5rem);
}

@media screen and (min-width: 481px) {
  .usa-search [type=search],
  .usa-search .usa-search-input {
    width: calc(100% - 8.5rem);
  }
}

.usa-search [type=submit],
.usa-search .usa-search-submit {
  background-image: url("../img/search.png");
  background-image: url("../img/search.svg");
  background-position: 50%;
  background-repeat: no-repeat;
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
  height: 3.3rem;
  margin: 0;
  padding: 0;
  width: 4.5rem;
}

@media screen and (min-width: 481px) {
  .usa-search [type=submit],
  .usa-search .usa-search-submit {
    background-image: none;
    width: 8.5rem;
  }
}

.usa-search .usa-search-submit-text {
  display: none;
}

@media screen and (min-width: 481px) {
  .usa-search .usa-search-submit-text {
    display: block;
  }
}

@media screen and (min-width: 481px) {
  .usa-search.usa-search-big [type=search],
  .usa-search.usa-search-big .usa-search-input {
    font-size: 1.7rem;
    height: 4.4rem;
    width: calc(100% - 11.6rem);
  }
  .usa-search.usa-search-big [type=submit],
  .usa-search.usa-search-big .usa-search-submit {
    font-size: 2rem;
    height: 4.4rem;
    width: 11.6rem;
  }
}

@media screen and (min-width: 481px) {
  .usa-search.usa-search-small [type=search],
  .usa-search.usa-search-small .usa-search-input {
    width: calc(100% - 4.5rem);
  }
  .usa-search.usa-search-small [type=submit],
  .usa-search.usa-search-small .usa-search-submit {
    background-image: url("../img/search.png");
    background-image: url("../img/search.svg");
    background-position: 50%;
    background-repeat: no-repeat;
    width: 4.5rem;
  }
}

@media screen and (max-width: 950px) {
  .usa-search.usa-search-small.usa-sr-only {
    left: auto;
    position: relative;
  }
}

.usa-section {
  padding-top: 3rem;
  padding-bottom: 3rem;
}

@media screen and (min-width: 600px) {
  .usa-section {
    padding-top: 6rem;
    padding-bottom: 6rem;
  }
}

.usa-section-light {
  background-color: #f1f1f1;
}

.usa-section-dark {
  background-color: #112e51;
  color: #ffffff;
}

.usa-section-dark h1,
.usa-section-dark h2,
.usa-section-dark h3,
.usa-section-dark h4,
.usa-section-dark h5,
.usa-section-dark h6 {
  color: #02bfe7;
}

.usa-section-dark p {
  color: #ffffff;
}

.usa-section-dark a {
  color: #d6d7d9;
}

.usa-section-dark a:hover {
  color: #ffffff;
}

.usa-sidenav-list {
  margin-top: 0;
  margin-bottom: 0;
  list-style-type: none;
  padding-left: 0;
}

.usa-sidenav-list > li {
  margin-bottom: 0;
}

.usa-sidenav-list > li {
  background-color: transparent;
  border-top: 1px solid #5b616b;
  font-size: 1.7rem;
}

.usa-sidenav-list > li:first-child {
  border-top: none;
}

.usa-sidenav-list a {
  border: none;
  color: #212121;
  display: block;
  font-family: "Source Sans Pro", "Helvetica Neue", "Helvetica", "Roboto", "Arial", sans-serif;
  line-height: 1.3;
  padding: 0.85rem 1rem 0.85rem 1.8rem;
  text-decoration: none;
}

.usa-sidenav-list a:hover {
  background-color: #f1f1f1;
  color: #0071bc;
  text-decoration: none;
}

.usa-sidenav-list a:focus {
  position: relative;
  z-index: 1;
}

.usa-sidenav-list a.usa-current {
  /* stylelint-disable-line selector-no-qualifying-type */
  border-left: 4px solid #0071bc;
  color: #0071bc;
  font-weight: 700;
  padding-left: 1.4rem;
}

.usa-sidenav-sub_list {
  margin-top: 0;
  margin-bottom: 0;
  list-style-type: none;
  padding-left: 0;
  margin: 0;
  width: 100%;
}

.usa-sidenav-sub_list > li {
  margin-bottom: 0;
}

.usa-sidenav-sub_list li {
  border: none;
  font-size: 1.5rem;
}

.usa-sidenav-sub_list a {
  padding-left: 2.8rem;
  line-height: 1.3;
}

.usa-sidenav-sub_list a:hover, .usa-sidenav-sub_list a.usa-current {
  /* stylelint-disable-line selector-no-qualifying-type */
  border: none;
  padding-left: 2.8rem;
}

.usa-sidenav-sub_list .usa-sidenav-sub_list a {
  padding-left: 3.8rem;
}

.usa-sidenav-sub_list .usa-sidenav-sub_list a:hover {
  padding-left: 3.8rem;
}

.usa-skipnav {
  background: transparent;
  color: #212121;
  left: 0;
  padding: 1rem 1.5rem;
  position: absolute;
  top: -4.2rem;
  transition: all 0.2s ease-in-out;
  z-index: 100;
}

.usa-skipnav:focus {
  background: #ffffff;
  left: 0;
  outline: 0;
  position: absolute;
  top: 0;
  transition: all 0.2s ease-in-out;
}
