<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  {% load staticfiles %}
  <link rel="stylesheet" href="{% static 'uswds-1.1.0/css/uswds.css' %}">
  <title>{% block title %}{% endblock %} - django-uswds-forms</title>
</head>
<body>
  <a class="usa-skipnav" href="#main-content">Skip to main content</a>
  {% include "header.html" %}
  <main class="usa-grid usa-section" id="main-content">
    {% block body %}{% endblock %}
  </main>
  <script src="{% static 'uswds-1.1.0/js/uswds.js' %}"></script>
</body>
</html>
