{% load staticfiles %}
<header class="usa-header usa-header-basic" role="banner">
  <div class="usa-nav-container">
    <div class="usa-navbar">
      <button class="usa-menu-btn">Menu</button>
      <div class="usa-logo" id="logo">
        <em class="usa-logo-text">
          <a href="{% url 'home' %}" title="Home" aria-label="Home">django-uswds-forms</a>
        </em>
      </div>
    </div>
    <nav role="navigation" class="usa-nav">
      <button class="usa-nav-close">
        <img src="{% static 'uswds-1.1.0/img/close.svg' %}" alt="close">
      </button>
      <ul class="usa-nav-primary usa-accordion">
        <li>
          <button class="
          usa-accordion-button usa-nav-link" aria-expanded="false" aria-controls="side-nav-1">
            <span>Examples</span>
          </button>
          <ul id="side-nav-1" class="usa-nav-submenu">
          {% for ex in EXAMPLES.values %}
            <li>
              <a href="{{ ex.url }}">{{ ex.name }}</a>
            </li>
          {% endfor %}
          </ul>
        </li>
        <li>
          <a class="usa-nav-link" href="{{ DOCS_URL }}">
            <span>Documentation</span>
          </a>
        </li>
        <li>
          <a class="usa-nav-link" href="https://github.com/18F/django-uswds-forms/">
            <span>GitHub</span>
          </a>
        </li>
      </ul>
    </nav>
  </div>
</header>
