"""
Django settings for example project.

Generated by 'django-admin startproject' using Django 1.8.

For more information on this file, see
https://docs.djangoproject.com/en/1.8/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/1.8/ref/settings/
"""

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
import os
import sys
from django.core.exceptions import ImproperlyConfigured

try:
    import whitenoise
except ImportError:
    whitenoise = None

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/1.8/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = 'this is a demo app'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

ALLOWED_HOSTS = ['*']


# Application definition

INSTALLED_APPS = (
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'uswds_forms',
    'app',
)

MIDDLEWARE_CLASSES = [
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'django.middleware.security.SecurityMiddleware',
]

if whitenoise is not None:
    # This is only needed for deploying on heroku/cloudfoundry/etc.
    MIDDLEWARE_CLASSES.insert(
        0,
        'whitenoise.middleware.WhiteNoiseMiddleware'
    )

ROOT_URLCONF = 'example.urls'

DJANGO_TEMPLATE_BACKEND = {
    'BACKEND': 'django.template.backends.django.DjangoTemplates',
    'DIRS': [],
    'APP_DIRS': True,
    'OPTIONS': {
        'context_processors': [
            'django.template.context_processors.debug',
            'django.template.context_processors.request',
            'django.contrib.auth.context_processors.auth',
            'django.contrib.messages.context_processors.messages',
        ],
    },
}

JINJA2_TEMPLATE_BACKEND = {
    'BACKEND': 'django.template.backends.jinja2.Jinja2',
    'DIRS': [],
    'APP_DIRS': True,
    'OPTIONS': {
        'environment': 'app.jinja2.environment',
    }
}

template_engine = os.environ.get('TEMPLATE_ENGINE', 'django')

if template_engine == 'jinja2':
    FORM_RENDERER = 'django.forms.renderers.Jinja2'
    TEMPLATES = [JINJA2_TEMPLATE_BACKEND, DJANGO_TEMPLATE_BACKEND]
elif template_engine == 'django':
    FORM_RENDERER = 'django.forms.renderers.DjangoTemplates'
    TEMPLATES = [DJANGO_TEMPLATE_BACKEND]
else:
    raise ImproperlyConfigured('Invalid TEMPLATE_ENGINE: ' + template_engine)

if len(sys.argv) > 1 and sys.argv[1] == 'runserver':
    print("Examples will be rendered using "
          "{} templates.".format(template_engine))

WSGI_APPLICATION = 'example.wsgi.application'


# Database
# https://docs.djangoproject.com/en/1.8/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
    }
}


# Internationalization
# https://docs.djangoproject.com/en/1.8/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/1.8/howto/static-files/

STATIC_URL = '/static/'

STATIC_ROOT = os.path.join(BASE_DIR, 'static')

DOCS_URL = "http://django-uswds-forms.readthedocs.io/en/latest/"
