{% include 'example_form_submission_alert.html' %}

<form method="post">
  {% csrf_token %}
  {{ form.as_fieldsets }}
  <button type="submit">Submit</button>
  <button type="submit" class="usa-button-secondary" formnovalidate>
    Submit without HTML5 form validation
  </button>
</form>
