{% extends "base.html" %}

{% block title %}Example gallery{% endblock %}

{% block body %}

<h1>Example gallery</h1>

<p>Welcome to the example gallery for django-uswds-forms! Here you can
see a variety of example forms alongside their Python and Django
template source code. Choose one from the list below to get started.</p>

<dl>
{% for ex in EXAMPLES.values %}
  <dt><a href="{{ ex.url }}">{{ ex.name }}</a></dt>
  <dd>{{ ex.description }}</dd>
{% endfor %}
</dl>

{% endblock %}
