{% include 'example_form_submission_alert.html' %}

<form method="post">
  {% csrf_token %}
  {% load uswds_forms %}
  {{ form.non_field_errors }}
  <ol>
    <li>{% fieldset form.president %}</li>
    <li>{% fieldset form.park %}</li>
    <li>{% fieldset form.states %}</li>
    <li>{% fieldset form.date %}</li>
  </ol>
  {% fieldset form.trigger_non_field_error %}
  <button type="submit">Submit</button>
  <button type="submit" class="usa-button-secondary" formnovalidate>
    Submit without HTML5 form validation
  </button>
</form>
